// This file has been generated by Py++.

#include "boost/python.hpp"
#include "generators/include/python_CEGUI.h"
#include "FrameWindow.pypp.hpp"

namespace bp = boost::python;

struct FrameWindow_wrapper : CEGUI::FrameWindow, bp::wrapper< CEGUI::FrameWindow > {

    FrameWindow_wrapper(::CEGUI::String const & type, ::CEGUI::String const & name )
    : CEGUI::FrameWindow( boost::ref(type), boost::ref(name) )
      , bp::wrapper< CEGUI::FrameWindow >(){
        // constructor
    
    }

    bool closeClickHandler( ::CEGUI::EventArgs const & e ){
        return CEGUI::FrameWindow::closeClickHandler( boost::ref(e) );
    }

    ::CEGUI::FrameWindow::SizingLocation getSizingBorderAtPoint( ::CEGUI::Vector2f const & pt ) const {
        return CEGUI::FrameWindow::getSizingBorderAtPoint( boost::ref(pt) );
    }

    virtual ::CEGUI::Rectf getSizingRect(  ) const {
        if( bp::override func_getSizingRect = this->get_override( "getSizingRect" ) )
            return func_getSizingRect(  );
        else{
            return this->CEGUI::FrameWindow::getSizingRect(  );
        }
    }
    
    virtual ::CEGUI::Rectf default_getSizingRect(  ) const {
        return CEGUI::FrameWindow::getSizingRect( );
    }

    virtual void initialiseComponents(  ) {
        if( bp::override func_initialiseComponents = this->get_override( "initialiseComponents" ) )
            func_initialiseComponents(  );
        else{
            this->CEGUI::FrameWindow::initialiseComponents(  );
        }
    }
    
    void default_initialiseComponents(  ) {
        CEGUI::FrameWindow::initialiseComponents( );
    }

    bool isBottomSizingLocation( ::CEGUI::FrameWindow::SizingLocation loc ) const {
        return CEGUI::FrameWindow::isBottomSizingLocation( loc );
    }

    virtual bool isHit( ::CEGUI::Vector2f const & position, bool const arg1 ) const  {
        if( bp::override func_isHit = this->get_override( "isHit" ) )
            return func_isHit( boost::ref(position), arg1 );
        else{
            return this->CEGUI::FrameWindow::isHit( boost::ref(position), arg1 );
        }
    }
    
    bool default_isHit( ::CEGUI::Vector2f const & position, bool const arg1 ) const  {
        return CEGUI::FrameWindow::isHit( boost::ref(position), arg1 );
    }

    bool isLeftSizingLocation( ::CEGUI::FrameWindow::SizingLocation loc ) const {
        return CEGUI::FrameWindow::isLeftSizingLocation( loc );
    }

    bool isRightSizingLocation( ::CEGUI::FrameWindow::SizingLocation loc ) const {
        return CEGUI::FrameWindow::isRightSizingLocation( loc );
    }

    bool isTopSizingLocation( ::CEGUI::FrameWindow::SizingLocation loc ) const {
        return CEGUI::FrameWindow::isTopSizingLocation( loc );
    }

    bool moveBottomEdge( float delta, ::CEGUI::URect & out_area ){
        return CEGUI::FrameWindow::moveBottomEdge( delta, boost::ref(out_area) );
    }

    bool moveLeftEdge( float delta, ::CEGUI::URect & out_area ){
        return CEGUI::FrameWindow::moveLeftEdge( delta, boost::ref(out_area) );
    }

    bool moveRightEdge( float delta, ::CEGUI::URect & out_area ){
        return CEGUI::FrameWindow::moveRightEdge( delta, boost::ref(out_area) );
    }

    bool moveTopEdge( float delta, ::CEGUI::URect & out_area ){
        return CEGUI::FrameWindow::moveTopEdge( delta, boost::ref(out_area) );
    }

    virtual void onActivated( ::CEGUI::ActivationEventArgs & e ){
        if( bp::override func_onActivated = this->get_override( "onActivated" ) )
            func_onActivated( boost::ref(e) );
        else{
            this->CEGUI::FrameWindow::onActivated( boost::ref(e) );
        }
    }
    
    virtual void default_onActivated( ::CEGUI::ActivationEventArgs & e ){
        CEGUI::FrameWindow::onActivated( boost::ref(e) );
    }

    virtual void onCaptureLost( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onCaptureLost = this->get_override( "onCaptureLost" ) )
            func_onCaptureLost( boost::ref(e) );
        else{
            this->CEGUI::FrameWindow::onCaptureLost( boost::ref(e) );
        }
    }
    
    virtual void default_onCaptureLost( ::CEGUI::WindowEventArgs & e ){
        CEGUI::FrameWindow::onCaptureLost( boost::ref(e) );
    }

    virtual void onCloseClicked( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onCloseClicked = this->get_override( "onCloseClicked" ) )
            func_onCloseClicked( boost::ref(e) );
        else{
            this->CEGUI::FrameWindow::onCloseClicked( boost::ref(e) );
        }
    }
    
    virtual void default_onCloseClicked( ::CEGUI::WindowEventArgs & e ){
        CEGUI::FrameWindow::onCloseClicked( boost::ref(e) );
    }

    virtual void onDeactivated( ::CEGUI::ActivationEventArgs & e ){
        if( bp::override func_onDeactivated = this->get_override( "onDeactivated" ) )
            func_onDeactivated( boost::ref(e) );
        else{
            this->CEGUI::FrameWindow::onDeactivated( boost::ref(e) );
        }
    }
    
    virtual void default_onDeactivated( ::CEGUI::ActivationEventArgs & e ){
        CEGUI::FrameWindow::onDeactivated( boost::ref(e) );
    }

    virtual void onDragSizingEnded( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onDragSizingEnded = this->get_override( "onDragSizingEnded" ) )
            func_onDragSizingEnded( boost::ref(e) );
        else{
            this->CEGUI::FrameWindow::onDragSizingEnded( boost::ref(e) );
        }
    }
    
    virtual void default_onDragSizingEnded( ::CEGUI::WindowEventArgs & e ){
        CEGUI::FrameWindow::onDragSizingEnded( boost::ref(e) );
    }

    virtual void onDragSizingStarted( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onDragSizingStarted = this->get_override( "onDragSizingStarted" ) )
            func_onDragSizingStarted( boost::ref(e) );
        else{
            this->CEGUI::FrameWindow::onDragSizingStarted( boost::ref(e) );
        }
    }
    
    virtual void default_onDragSizingStarted( ::CEGUI::WindowEventArgs & e ){
        CEGUI::FrameWindow::onDragSizingStarted( boost::ref(e) );
    }

    virtual void onMouseButtonDown( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseButtonDown = this->get_override( "onMouseButtonDown" ) )
            func_onMouseButtonDown( boost::ref(e) );
        else{
            this->CEGUI::FrameWindow::onMouseButtonDown( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseButtonDown( ::CEGUI::MouseEventArgs & e ){
        CEGUI::FrameWindow::onMouseButtonDown( boost::ref(e) );
    }

    virtual void onMouseButtonUp( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseButtonUp = this->get_override( "onMouseButtonUp" ) )
            func_onMouseButtonUp( boost::ref(e) );
        else{
            this->CEGUI::FrameWindow::onMouseButtonUp( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseButtonUp( ::CEGUI::MouseEventArgs & e ){
        CEGUI::FrameWindow::onMouseButtonUp( boost::ref(e) );
    }

    virtual void onMouseMove( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseMove = this->get_override( "onMouseMove" ) )
            func_onMouseMove( boost::ref(e) );
        else{
            this->CEGUI::FrameWindow::onMouseMove( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseMove( ::CEGUI::MouseEventArgs & e ){
        CEGUI::FrameWindow::onMouseMove( boost::ref(e) );
    }

    virtual void onRollupToggled( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onRollupToggled = this->get_override( "onRollupToggled" ) )
            func_onRollupToggled( boost::ref(e) );
        else{
            this->CEGUI::FrameWindow::onRollupToggled( boost::ref(e) );
        }
    }
    
    virtual void default_onRollupToggled( ::CEGUI::WindowEventArgs & e ){
        CEGUI::FrameWindow::onRollupToggled( boost::ref(e) );
    }

    virtual void onTextChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onTextChanged = this->get_override( "onTextChanged" ) )
            func_onTextChanged( boost::ref(e) );
        else{
            this->CEGUI::FrameWindow::onTextChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onTextChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::FrameWindow::onTextChanged( boost::ref(e) );
    }

    void setCursorForPoint( ::CEGUI::Vector2f const & pt ) const {
        CEGUI::FrameWindow::setCursorForPoint( boost::ref(pt) );
    }

    virtual void addChild_impl( ::CEGUI::Element * element ){
        if( bp::override func_addChild_impl = this->get_override( "addChild_impl" ) )
            func_addChild_impl( boost::python::ptr(element) );
        else{
            this->CEGUI::Window::addChild_impl( boost::python::ptr(element) );
        }
    }
    
    virtual void default_addChild_impl( ::CEGUI::Element * element ){
        CEGUI::Window::addChild_impl( boost::python::ptr(element) );
    }

    void addElementProperties(  ){
        CEGUI::Element::addElementProperties(  );
    }

    void addNamedElementProperties(  ){
        CEGUI::NamedElement::addNamedElementProperties(  );
    }

    void addWindowProperties(  ){
        CEGUI::Window::addWindowProperties(  );
    }

    void addWindowToDrawList( ::CEGUI::Window & wnd, bool at_back=false ){
        CEGUI::Window::addWindowToDrawList( boost::ref(wnd), at_back );
    }

    void allocateRenderingWindow(  ){
        CEGUI::Window::allocateRenderingWindow(  );
    }

    virtual void banPropertiesForAutoWindow(  ){
        if( bp::override func_banPropertiesForAutoWindow = this->get_override( "banPropertiesForAutoWindow" ) )
            func_banPropertiesForAutoWindow(  );
        else{
            this->CEGUI::Window::banPropertiesForAutoWindow(  );
        }
    }
    
    virtual void default_banPropertiesForAutoWindow(  ){
        CEGUI::Window::banPropertiesForAutoWindow( );
    }

    virtual void beginInitialisation(  ) {
        if( bp::override func_beginInitialisation = this->get_override( "beginInitialisation" ) )
            func_beginInitialisation(  );
        else{
            this->CEGUI::Window::beginInitialisation(  );
        }
    }
    
    void default_beginInitialisation(  ) {
        CEGUI::Window::beginInitialisation( );
    }

    void bufferGeometry( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::bufferGeometry( boost::ref(ctx) );
    }

    virtual void cleanupChildren(  ){
        if( bp::override func_cleanupChildren = this->get_override( "cleanupChildren" ) )
            func_cleanupChildren(  );
        else{
            this->CEGUI::Window::cleanupChildren(  );
        }
    }
    
    virtual void default_cleanupChildren(  ){
        CEGUI::Window::cleanupChildren( );
    }

    virtual void cloneChildWidgetsTo( ::CEGUI::Window & target ) const  {
        if( bp::override func_cloneChildWidgetsTo = this->get_override( "cloneChildWidgetsTo" ) )
            func_cloneChildWidgetsTo( boost::ref(target) );
        else{
            this->CEGUI::Window::cloneChildWidgetsTo( boost::ref(target) );
        }
    }
    
    void default_cloneChildWidgetsTo( ::CEGUI::Window & target ) const  {
        CEGUI::Window::cloneChildWidgetsTo( boost::ref(target) );
    }

    virtual void clonePropertiesTo( ::CEGUI::Window & target ) const  {
        if( bp::override func_clonePropertiesTo = this->get_override( "clonePropertiesTo" ) )
            func_clonePropertiesTo( boost::ref(target) );
        else{
            this->CEGUI::Window::clonePropertiesTo( boost::ref(target) );
        }
    }
    
    void default_clonePropertiesTo( ::CEGUI::Window & target ) const  {
        CEGUI::Window::clonePropertiesTo( boost::ref(target) );
    }

    virtual void destroy(  ) {
        if( bp::override func_destroy = this->get_override( "destroy" ) )
            func_destroy(  );
        else{
            this->CEGUI::Window::destroy(  );
        }
    }
    
    void default_destroy(  ) {
        CEGUI::Window::destroy( );
    }

    virtual void drawSelf( ::CEGUI::RenderingContext const & ctx ){
        if( bp::override func_drawSelf = this->get_override( "drawSelf" ) )
            func_drawSelf( boost::ref(ctx) );
        else{
            this->CEGUI::Window::drawSelf( boost::ref(ctx) );
        }
    }
    
    virtual void default_drawSelf( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::drawSelf( boost::ref(ctx) );
    }

    virtual void endInitialisation(  ) {
        if( bp::override func_endInitialisation = this->get_override( "endInitialisation" ) )
            func_endInitialisation(  );
        else{
            this->CEGUI::Window::endInitialisation(  );
        }
    }
    
    void default_endInitialisation(  ) {
        CEGUI::Window::endInitialisation( );
    }

    void fireAreaChangeEvents( bool const moved, bool const sized ){
        CEGUI::Element::fireAreaChangeEvents( moved, sized );
    }

    virtual void fireEvent( ::CEGUI::String const & name, ::CEGUI::EventArgs & args, ::CEGUI::String const & eventNamespace="" ) {
        if( bp::override func_fireEvent = this->get_override( "fireEvent" ) )
            func_fireEvent( boost::ref(name), boost::ref(args), boost::ref(eventNamespace) );
        else{
            this->CEGUI::EventSet::fireEvent( boost::ref(name), boost::ref(args), boost::ref(eventNamespace) );
        }
    }
    
    void default_fireEvent( ::CEGUI::String const & name, ::CEGUI::EventArgs & args, ::CEGUI::String const & eventNamespace="" ) {
        CEGUI::EventSet::fireEvent( boost::ref(name), boost::ref(args), boost::ref(eventNamespace) );
    }

    void fireEvent_impl( ::CEGUI::String const & name, ::CEGUI::EventArgs & args ){
        CEGUI::EventSet::fireEvent_impl( boost::ref(name), boost::ref(args) );
    }

    void generateAutoRepeatEvent( ::CEGUI::MouseButton button ){
        CEGUI::Window::generateAutoRepeatEvent( button );
    }

    virtual ::CEGUI::NamedElement * getChildByNamePath_impl( ::CEGUI::String const & name_path ) const {
        if( bp::override func_getChildByNamePath_impl = this->get_override( "getChildByNamePath_impl" ) )
            return func_getChildByNamePath_impl( boost::ref(name_path) );
        else{
            return this->CEGUI::NamedElement::getChildByNamePath_impl( boost::ref(name_path) );
        }
    }
    
    virtual ::CEGUI::NamedElement * default_getChildByNamePath_impl( ::CEGUI::String const & name_path ) const {
        return CEGUI::NamedElement::getChildByNamePath_impl( boost::ref(name_path) );
    }

    virtual ::CEGUI::NamedElement * getChildByNameRecursive_impl( ::CEGUI::String const & name ) const {
        if( bp::override func_getChildByNameRecursive_impl = this->get_override( "getChildByNameRecursive_impl" ) )
            return func_getChildByNameRecursive_impl( boost::ref(name) );
        else{
            return this->CEGUI::NamedElement::getChildByNameRecursive_impl( boost::ref(name) );
        }
    }
    
    virtual ::CEGUI::NamedElement * default_getChildByNameRecursive_impl( ::CEGUI::String const & name ) const {
        return CEGUI::NamedElement::getChildByNameRecursive_impl( boost::ref(name) );
    }

    virtual ::CEGUI::Rectf getHitTestRect_impl(  ) const {
        if( bp::override func_getHitTestRect_impl = this->get_override( "getHitTestRect_impl" ) )
            return func_getHitTestRect_impl(  );
        else{
            return this->CEGUI::Window::getHitTestRect_impl(  );
        }
    }
    
    virtual ::CEGUI::Rectf default_getHitTestRect_impl(  ) const {
        return CEGUI::Window::getHitTestRect_impl( );
    }

    virtual ::CEGUI::Rectf getInnerRectClipper_impl(  ) const {
        if( bp::override func_getInnerRectClipper_impl = this->get_override( "getInnerRectClipper_impl" ) )
            return func_getInnerRectClipper_impl(  );
        else{
            return this->CEGUI::Window::getInnerRectClipper_impl(  );
        }
    }
    
    virtual ::CEGUI::Rectf default_getInnerRectClipper_impl(  ) const {
        return CEGUI::Window::getInnerRectClipper_impl( );
    }

    virtual ::CEGUI::Rectf getOuterRectClipper_impl(  ) const {
        if( bp::override func_getOuterRectClipper_impl = this->get_override( "getOuterRectClipper_impl" ) )
            return func_getOuterRectClipper_impl(  );
        else{
            return this->CEGUI::Window::getOuterRectClipper_impl(  );
        }
    }
    
    virtual ::CEGUI::Rectf default_getOuterRectClipper_impl(  ) const {
        return CEGUI::Window::getOuterRectClipper_impl( );
    }

    ::CEGUI::Rectf getParentElementClipIntersection( ::CEGUI::Rectf const & unclipped_area ) const {
        return CEGUI::Window::getParentElementClipIntersection( boost::ref(unclipped_area) );
    }

    virtual void getRenderingContext_impl( ::CEGUI::RenderingContext & ctx ) const  {
        if( bp::override func_getRenderingContext_impl = this->get_override( "getRenderingContext_impl" ) )
            func_getRenderingContext_impl( boost::ref(ctx) );
        else{
            this->CEGUI::Window::getRenderingContext_impl( boost::ref(ctx) );
        }
    }
    
    void default_getRenderingContext_impl( ::CEGUI::RenderingContext & ctx ) const  {
        CEGUI::Window::getRenderingContext_impl( boost::ref(ctx) );
    }

    ::CEGUI::ScriptModule * getScriptModule(  ) const {
        return CEGUI::EventSet::getScriptModule(  );
    }

    virtual ::CEGUI::Rectf getUnclippedInnerRect_impl( bool skipAllPixelAlignment ) const {
        if( bp::override func_getUnclippedInnerRect_impl = this->get_override( "getUnclippedInnerRect_impl" ) )
            return func_getUnclippedInnerRect_impl( skipAllPixelAlignment );
        else{
            return this->CEGUI::Window::getUnclippedInnerRect_impl( skipAllPixelAlignment );
        }
    }
    
    virtual ::CEGUI::Rectf default_getUnclippedInnerRect_impl( bool skipAllPixelAlignment ) const {
        return CEGUI::Window::getUnclippedInnerRect_impl( skipAllPixelAlignment );
    }

    virtual ::CEGUI::Rectf getUnclippedOuterRect_impl( bool skipAllPixelAlignment ) const {
        if( bp::override func_getUnclippedOuterRect_impl = this->get_override( "getUnclippedOuterRect_impl" ) )
            return func_getUnclippedOuterRect_impl( skipAllPixelAlignment );
        else{
            return this->CEGUI::Element::getUnclippedOuterRect_impl( skipAllPixelAlignment );
        }
    }
    
    virtual ::CEGUI::Rectf default_getUnclippedOuterRect_impl( bool skipAllPixelAlignment ) const {
        return CEGUI::Element::getUnclippedOuterRect_impl( skipAllPixelAlignment );
    }

    ::CEGUI::Window const * getWindowAttachedToCommonAncestor( ::CEGUI::Window const & wnd ) const {
        return CEGUI::Window::getWindowAttachedToCommonAncestor( boost::ref(wnd) );
    }

    virtual bool handleFontRenderSizeChange( ::CEGUI::EventArgs const & args ){
        if( bp::override func_handleFontRenderSizeChange = this->get_override( "handleFontRenderSizeChange" ) )
            return func_handleFontRenderSizeChange( boost::ref(args) );
        else{
            return this->CEGUI::Window::handleFontRenderSizeChange( boost::ref(args) );
        }
    }
    
    virtual bool default_handleFontRenderSizeChange( ::CEGUI::EventArgs const & args ){
        return CEGUI::Window::handleFontRenderSizeChange( boost::ref(args) );
    }

    void initialiseClippers( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::initialiseClippers( boost::ref(ctx) );
    }

    void invalidate_impl( bool const recursive ){
        CEGUI::Window::invalidate_impl( recursive );
    }

    bool isHitTargetWindow( ::CEGUI::Vector2f const & position, bool allow_disabled ) const {
        return CEGUI::Window::isHitTargetWindow( boost::ref(position), allow_disabled );
    }

    bool isInnerRectSizeChanged(  ) const {
        return CEGUI::Element::isInnerRectSizeChanged(  );
    }

    bool isPropertyAtDefault( ::CEGUI::Property const * property ) const {
        return CEGUI::Window::isPropertyAtDefault( boost::python::ptr(property) );
    }

    bool isTopOfZOrder(  ) const {
        return CEGUI::Window::isTopOfZOrder(  );
    }

    void layoutLookNFeelChildWidgets(  ){
        CEGUI::Window::layoutLookNFeelChildWidgets(  );
    }

    void markCachedWindowRectsInvalid(  ){
        CEGUI::Window::markCachedWindowRectsInvalid(  );
    }

    virtual bool moveToFront_impl( bool wasClicked ){
        if( bp::override func_moveToFront_impl = this->get_override( "moveToFront_impl" ) )
            return func_moveToFront_impl( wasClicked );
        else{
            return this->CEGUI::Window::moveToFront_impl( wasClicked );
        }
    }
    
    virtual bool default_moveToFront_impl( bool wasClicked ){
        return CEGUI::Window::moveToFront_impl( wasClicked );
    }

    void notifyChildrenOfSizeChange( bool const non_client, bool const client ){
        CEGUI::Element::notifyChildrenOfSizeChange( non_client, client );
    }

    void notifyClippingChanged(  ){
        CEGUI::Window::notifyClippingChanged(  );
    }

    virtual void notifyScreenAreaChanged( bool recursive=true ) {
        if( bp::override func_notifyScreenAreaChanged = this->get_override( "notifyScreenAreaChanged" ) )
            func_notifyScreenAreaChanged( recursive );
        else{
            this->CEGUI::Window::notifyScreenAreaChanged( recursive );
        }
    }
    
    void default_notifyScreenAreaChanged( bool recursive=true ) {
        CEGUI::Window::notifyScreenAreaChanged( recursive );
    }

    virtual void onAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onAlphaChanged = this->get_override( "onAlphaChanged" ) )
            func_onAlphaChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onAlphaChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onAlphaChanged( boost::ref(e) );
    }

    virtual void onAlwaysOnTopChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onAlwaysOnTopChanged = this->get_override( "onAlwaysOnTopChanged" ) )
            func_onAlwaysOnTopChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onAlwaysOnTopChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onAlwaysOnTopChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onAlwaysOnTopChanged( boost::ref(e) );
    }

    virtual void onCaptureGained( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onCaptureGained = this->get_override( "onCaptureGained" ) )
            func_onCaptureGained( boost::ref(e) );
        else{
            this->CEGUI::Window::onCaptureGained( boost::ref(e) );
        }
    }
    
    virtual void default_onCaptureGained( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onCaptureGained( boost::ref(e) );
    }

    virtual void onCharacter( ::CEGUI::KeyEventArgs & e ){
        if( bp::override func_onCharacter = this->get_override( "onCharacter" ) )
            func_onCharacter( boost::ref(e) );
        else{
            this->CEGUI::Window::onCharacter( boost::ref(e) );
        }
    }
    
    virtual void default_onCharacter( ::CEGUI::KeyEventArgs & e ){
        CEGUI::Window::onCharacter( boost::ref(e) );
    }

    virtual void onChildAdded( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onChildAdded = this->get_override( "onChildAdded" ) )
            func_onChildAdded( boost::ref(e) );
        else{
            this->CEGUI::Window::onChildAdded( boost::ref(e) );
        }
    }
    
    virtual void default_onChildAdded( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onChildAdded( boost::ref(e) );
    }

    virtual void onChildRemoved( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onChildRemoved = this->get_override( "onChildRemoved" ) )
            func_onChildRemoved( boost::ref(e) );
        else{
            this->CEGUI::Window::onChildRemoved( boost::ref(e) );
        }
    }
    
    virtual void default_onChildRemoved( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onChildRemoved( boost::ref(e) );
    }

    virtual void onClippingChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onClippingChanged = this->get_override( "onClippingChanged" ) )
            func_onClippingChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onClippingChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onClippingChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onClippingChanged( boost::ref(e) );
    }

    virtual void onDestructionStarted( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onDestructionStarted = this->get_override( "onDestructionStarted" ) )
            func_onDestructionStarted( boost::ref(e) );
        else{
            this->CEGUI::Window::onDestructionStarted( boost::ref(e) );
        }
    }
    
    virtual void default_onDestructionStarted( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onDestructionStarted( boost::ref(e) );
    }

    virtual void onDisabled( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onDisabled = this->get_override( "onDisabled" ) )
            func_onDisabled( boost::ref(e) );
        else{
            this->CEGUI::Window::onDisabled( boost::ref(e) );
        }
    }
    
    virtual void default_onDisabled( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onDisabled( boost::ref(e) );
    }

    virtual void onDragDropItemDropped( ::CEGUI::DragDropEventArgs & e ){
        if( bp::override func_onDragDropItemDropped = this->get_override( "onDragDropItemDropped" ) )
            func_onDragDropItemDropped( boost::ref(e) );
        else{
            this->CEGUI::Window::onDragDropItemDropped( boost::ref(e) );
        }
    }
    
    virtual void default_onDragDropItemDropped( ::CEGUI::DragDropEventArgs & e ){
        CEGUI::Window::onDragDropItemDropped( boost::ref(e) );
    }

    virtual void onDragDropItemEnters( ::CEGUI::DragDropEventArgs & e ){
        if( bp::override func_onDragDropItemEnters = this->get_override( "onDragDropItemEnters" ) )
            func_onDragDropItemEnters( boost::ref(e) );
        else{
            this->CEGUI::Window::onDragDropItemEnters( boost::ref(e) );
        }
    }
    
    virtual void default_onDragDropItemEnters( ::CEGUI::DragDropEventArgs & e ){
        CEGUI::Window::onDragDropItemEnters( boost::ref(e) );
    }

    virtual void onDragDropItemLeaves( ::CEGUI::DragDropEventArgs & e ){
        if( bp::override func_onDragDropItemLeaves = this->get_override( "onDragDropItemLeaves" ) )
            func_onDragDropItemLeaves( boost::ref(e) );
        else{
            this->CEGUI::Window::onDragDropItemLeaves( boost::ref(e) );
        }
    }
    
    virtual void default_onDragDropItemLeaves( ::CEGUI::DragDropEventArgs & e ){
        CEGUI::Window::onDragDropItemLeaves( boost::ref(e) );
    }

    virtual void onEnabled( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onEnabled = this->get_override( "onEnabled" ) )
            func_onEnabled( boost::ref(e) );
        else{
            this->CEGUI::Window::onEnabled( boost::ref(e) );
        }
    }
    
    virtual void default_onEnabled( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onEnabled( boost::ref(e) );
    }

    virtual void onFontChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onFontChanged = this->get_override( "onFontChanged" ) )
            func_onFontChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onFontChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onFontChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onFontChanged( boost::ref(e) );
    }

    virtual void onHidden( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onHidden = this->get_override( "onHidden" ) )
            func_onHidden( boost::ref(e) );
        else{
            this->CEGUI::Window::onHidden( boost::ref(e) );
        }
    }
    
    virtual void default_onHidden( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onHidden( boost::ref(e) );
    }

    virtual void onHorizontalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onHorizontalAlignmentChanged = this->get_override( "onHorizontalAlignmentChanged" ) )
            func_onHorizontalAlignmentChanged( boost::ref(e) );
        else{
            this->CEGUI::Element::onHorizontalAlignmentChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onHorizontalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Element::onHorizontalAlignmentChanged( boost::ref(e) );
    }

    virtual void onIDChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onIDChanged = this->get_override( "onIDChanged" ) )
            func_onIDChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onIDChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onIDChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onIDChanged( boost::ref(e) );
    }

    virtual void onInheritsAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onInheritsAlphaChanged = this->get_override( "onInheritsAlphaChanged" ) )
            func_onInheritsAlphaChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onInheritsAlphaChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onInheritsAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onInheritsAlphaChanged( boost::ref(e) );
    }

    virtual void onInvalidated( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onInvalidated = this->get_override( "onInvalidated" ) )
            func_onInvalidated( boost::ref(e) );
        else{
            this->CEGUI::Window::onInvalidated( boost::ref(e) );
        }
    }
    
    virtual void default_onInvalidated( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onInvalidated( boost::ref(e) );
    }

    virtual void onKeyDown( ::CEGUI::KeyEventArgs & e ){
        if( bp::override func_onKeyDown = this->get_override( "onKeyDown" ) )
            func_onKeyDown( boost::ref(e) );
        else{
            this->CEGUI::Window::onKeyDown( boost::ref(e) );
        }
    }
    
    virtual void default_onKeyDown( ::CEGUI::KeyEventArgs & e ){
        CEGUI::Window::onKeyDown( boost::ref(e) );
    }

    virtual void onKeyUp( ::CEGUI::KeyEventArgs & e ){
        if( bp::override func_onKeyUp = this->get_override( "onKeyUp" ) )
            func_onKeyUp( boost::ref(e) );
        else{
            this->CEGUI::Window::onKeyUp( boost::ref(e) );
        }
    }
    
    virtual void default_onKeyUp( ::CEGUI::KeyEventArgs & e ){
        CEGUI::Window::onKeyUp( boost::ref(e) );
    }

    virtual void onMarginChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onMarginChanged = this->get_override( "onMarginChanged" ) )
            func_onMarginChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onMarginChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onMarginChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onMarginChanged( boost::ref(e) );
    }

    virtual void onMouseClicked( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseClicked = this->get_override( "onMouseClicked" ) )
            func_onMouseClicked( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseClicked( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseClicked( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseClicked( boost::ref(e) );
    }

    virtual void onMouseDoubleClicked( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseDoubleClicked = this->get_override( "onMouseDoubleClicked" ) )
            func_onMouseDoubleClicked( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseDoubleClicked( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseDoubleClicked( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseDoubleClicked( boost::ref(e) );
    }

    virtual void onMouseEnters( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseEnters = this->get_override( "onMouseEnters" ) )
            func_onMouseEnters( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseEnters( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseEnters( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseEnters( boost::ref(e) );
    }

    virtual void onMouseEntersArea( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseEntersArea = this->get_override( "onMouseEntersArea" ) )
            func_onMouseEntersArea( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseEntersArea( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseEntersArea( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseEntersArea( boost::ref(e) );
    }

    virtual void onMouseLeaves( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseLeaves = this->get_override( "onMouseLeaves" ) )
            func_onMouseLeaves( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseLeaves( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseLeaves( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseLeaves( boost::ref(e) );
    }

    virtual void onMouseLeavesArea( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseLeavesArea = this->get_override( "onMouseLeavesArea" ) )
            func_onMouseLeavesArea( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseLeavesArea( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseLeavesArea( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseLeavesArea( boost::ref(e) );
    }

    virtual void onMouseTripleClicked( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseTripleClicked = this->get_override( "onMouseTripleClicked" ) )
            func_onMouseTripleClicked( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseTripleClicked( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseTripleClicked( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseTripleClicked( boost::ref(e) );
    }

    virtual void onMouseWheel( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseWheel = this->get_override( "onMouseWheel" ) )
            func_onMouseWheel( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseWheel( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseWheel( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseWheel( boost::ref(e) );
    }

    virtual void onMoved( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onMoved = this->get_override( "onMoved" ) )
            func_onMoved( boost::ref(e) );
        else{
            this->CEGUI::Window::onMoved( boost::ref(e) );
        }
    }
    
    virtual void default_onMoved( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onMoved( boost::ref(e) );
    }

    virtual void onNameChanged( ::CEGUI::NamedElementEventArgs & e ){
        if( bp::override func_onNameChanged = this->get_override( "onNameChanged" ) )
            func_onNameChanged( boost::ref(e) );
        else{
            this->CEGUI::NamedElement::onNameChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onNameChanged( ::CEGUI::NamedElementEventArgs & e ){
        CEGUI::NamedElement::onNameChanged( boost::ref(e) );
    }

    virtual void onNonClientChanged( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onNonClientChanged = this->get_override( "onNonClientChanged" ) )
            func_onNonClientChanged( boost::ref(e) );
        else{
            this->CEGUI::Element::onNonClientChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onNonClientChanged( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Element::onNonClientChanged( boost::ref(e) );
    }

    virtual void onParentDestroyChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onParentDestroyChanged = this->get_override( "onParentDestroyChanged" ) )
            func_onParentDestroyChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onParentDestroyChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onParentDestroyChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onParentDestroyChanged( boost::ref(e) );
    }

    virtual void onParentSized( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onParentSized = this->get_override( "onParentSized" ) )
            func_onParentSized( boost::ref(e) );
        else{
            this->CEGUI::Window::onParentSized( boost::ref(e) );
        }
    }
    
    virtual void default_onParentSized( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onParentSized( boost::ref(e) );
    }

    virtual void onRenderingEnded( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onRenderingEnded = this->get_override( "onRenderingEnded" ) )
            func_onRenderingEnded( boost::ref(e) );
        else{
            this->CEGUI::Window::onRenderingEnded( boost::ref(e) );
        }
    }
    
    virtual void default_onRenderingEnded( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onRenderingEnded( boost::ref(e) );
    }

    virtual void onRenderingStarted( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onRenderingStarted = this->get_override( "onRenderingStarted" ) )
            func_onRenderingStarted( boost::ref(e) );
        else{
            this->CEGUI::Window::onRenderingStarted( boost::ref(e) );
        }
    }
    
    virtual void default_onRenderingStarted( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onRenderingStarted( boost::ref(e) );
    }

    virtual void onRotated( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onRotated = this->get_override( "onRotated" ) )
            func_onRotated( boost::ref(e) );
        else{
            this->CEGUI::Window::onRotated( boost::ref(e) );
        }
    }
    
    virtual void default_onRotated( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onRotated( boost::ref(e) );
    }

    virtual void onShown( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onShown = this->get_override( "onShown" ) )
            func_onShown( boost::ref(e) );
        else{
            this->CEGUI::Window::onShown( boost::ref(e) );
        }
    }
    
    virtual void default_onShown( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onShown( boost::ref(e) );
    }

    virtual void onSized( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onSized = this->get_override( "onSized" ) )
            func_onSized( boost::ref(e) );
        else{
            this->CEGUI::Window::onSized( boost::ref(e) );
        }
    }
    
    virtual void default_onSized( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onSized( boost::ref(e) );
    }

    virtual void onTextParsingChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onTextParsingChanged = this->get_override( "onTextParsingChanged" ) )
            func_onTextParsingChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onTextParsingChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onTextParsingChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onTextParsingChanged( boost::ref(e) );
    }

    virtual void onVerticalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onVerticalAlignmentChanged = this->get_override( "onVerticalAlignmentChanged" ) )
            func_onVerticalAlignmentChanged( boost::ref(e) );
        else{
            this->CEGUI::Element::onVerticalAlignmentChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onVerticalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Element::onVerticalAlignmentChanged( boost::ref(e) );
    }

    virtual void onWindowRendererAttached( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onWindowRendererAttached = this->get_override( "onWindowRendererAttached" ) )
            func_onWindowRendererAttached( boost::ref(e) );
        else{
            this->CEGUI::Window::onWindowRendererAttached( boost::ref(e) );
        }
    }
    
    virtual void default_onWindowRendererAttached( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onWindowRendererAttached( boost::ref(e) );
    }

    virtual void onWindowRendererDetached( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onWindowRendererDetached = this->get_override( "onWindowRendererDetached" ) )
            func_onWindowRendererDetached( boost::ref(e) );
        else{
            this->CEGUI::Window::onWindowRendererDetached( boost::ref(e) );
        }
    }
    
    virtual void default_onWindowRendererDetached( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onWindowRendererDetached( boost::ref(e) );
    }

    virtual void onZChange_impl(  ){
        if( bp::override func_onZChange_impl = this->get_override( "onZChange_impl" ) )
            func_onZChange_impl(  );
        else{
            this->CEGUI::Window::onZChange_impl(  );
        }
    }
    
    virtual void default_onZChange_impl(  ){
        CEGUI::Window::onZChange_impl( );
    }

    virtual void onZChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onZChanged = this->get_override( "onZChanged" ) )
            func_onZChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onZChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onZChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onZChanged( boost::ref(e) );
    }

    virtual void performChildWindowLayout( bool nonclient_sized_hint=false, bool client_sized_hint=false ) {
        if( bp::override func_performChildWindowLayout = this->get_override( "performChildWindowLayout" ) )
            func_performChildWindowLayout( nonclient_sized_hint, client_sized_hint );
        else{
            this->CEGUI::Window::performChildWindowLayout( nonclient_sized_hint, client_sized_hint );
        }
    }
    
    void default_performChildWindowLayout( bool nonclient_sized_hint=false, bool client_sized_hint=false ) {
        CEGUI::Window::performChildWindowLayout( nonclient_sized_hint, client_sized_hint );
    }

    virtual bool performCopy( ::CEGUI::Clipboard & clipboard ) {
        if( bp::override func_performCopy = this->get_override( "performCopy" ) )
            return func_performCopy( boost::ref(clipboard) );
        else{
            return this->CEGUI::Window::performCopy( boost::ref(clipboard) );
        }
    }
    
    bool default_performCopy( ::CEGUI::Clipboard & clipboard ) {
        return CEGUI::Window::performCopy( boost::ref(clipboard) );
    }

    virtual bool performCut( ::CEGUI::Clipboard & clipboard ) {
        if( bp::override func_performCut = this->get_override( "performCut" ) )
            return func_performCut( boost::ref(clipboard) );
        else{
            return this->CEGUI::Window::performCut( boost::ref(clipboard) );
        }
    }
    
    bool default_performCut( ::CEGUI::Clipboard & clipboard ) {
        return CEGUI::Window::performCut( boost::ref(clipboard) );
    }

    virtual bool performPaste( ::CEGUI::Clipboard & clipboard ) {
        if( bp::override func_performPaste = this->get_override( "performPaste" ) )
            return func_performPaste( boost::ref(clipboard) );
        else{
            return this->CEGUI::Window::performPaste( boost::ref(clipboard) );
        }
    }
    
    bool default_performPaste( ::CEGUI::Clipboard & clipboard ) {
        return CEGUI::Window::performPaste( boost::ref(clipboard) );
    }

    virtual void populateGeometryBuffer(  ){
        if( bp::override func_populateGeometryBuffer = this->get_override( "populateGeometryBuffer" ) )
            func_populateGeometryBuffer(  );
        else{
            this->CEGUI::Window::populateGeometryBuffer(  );
        }
    }
    
    virtual void default_populateGeometryBuffer(  ){
        CEGUI::Window::populateGeometryBuffer( );
    }

    void queueGeometry( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::queueGeometry( boost::ref(ctx) );
    }

    void releaseRenderingWindow(  ){
        CEGUI::Window::releaseRenderingWindow(  );
    }

    virtual void removeChild_impl( ::CEGUI::Element * element ){
        if( bp::override func_removeChild_impl = this->get_override( "removeChild_impl" ) )
            func_removeChild_impl( boost::python::ptr(element) );
        else{
            this->CEGUI::Window::removeChild_impl( boost::python::ptr(element) );
        }
    }
    
    virtual void default_removeChild_impl( ::CEGUI::Element * element ){
        CEGUI::Window::removeChild_impl( boost::python::ptr(element) );
    }

    void removeWindowFromDrawList( ::CEGUI::Window const & wnd ){
        CEGUI::Window::removeWindowFromDrawList( boost::ref(wnd) );
    }

    virtual void setArea( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size ) {
        if( bp::override func_setArea = this->get_override( "setArea" ) )
            func_setArea( boost::ref(pos), boost::ref(size) );
        else{
            this->CEGUI::Element::setArea( boost::ref(pos), boost::ref(size) );
        }
    }
    
    void default_setArea( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size ) {
        CEGUI::Element::setArea( boost::ref(pos), boost::ref(size) );
    }

    virtual void setArea_impl( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size, bool topLeftSizing=false, bool fireEvents=true ){
        if( bp::override func_setArea_impl = this->get_override( "setArea_impl" ) )
            func_setArea_impl( boost::ref(pos), boost::ref(size), topLeftSizing, fireEvents );
        else{
            this->CEGUI::Window::setArea_impl( boost::ref(pos), boost::ref(size), topLeftSizing, fireEvents );
        }
    }
    
    virtual void default_setArea_impl( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size, bool topLeftSizing=false, bool fireEvents=true ){
        CEGUI::Window::setArea_impl( boost::ref(pos), boost::ref(size), topLeftSizing, fireEvents );
    }

    virtual void setHorizontalAlignment( ::CEGUI::HorizontalAlignment const alignment ) {
        if( bp::override func_setHorizontalAlignment = this->get_override( "setHorizontalAlignment" ) )
            func_setHorizontalAlignment( alignment );
        else{
            this->CEGUI::Element::setHorizontalAlignment( alignment );
        }
    }
    
    void default_setHorizontalAlignment( ::CEGUI::HorizontalAlignment const alignment ) {
        CEGUI::Element::setHorizontalAlignment( alignment );
    }

    virtual void setLookNFeel( ::CEGUI::String const & look ) {
        if( bp::override func_setLookNFeel = this->get_override( "setLookNFeel" ) )
            func_setLookNFeel( boost::ref(look) );
        else{
            this->CEGUI::Window::setLookNFeel( boost::ref(look) );
        }
    }
    
    void default_setLookNFeel( ::CEGUI::String const & look ) {
        CEGUI::Window::setLookNFeel( boost::ref(look) );
    }

    virtual void setMargin( ::CEGUI::UBox const & margin ) {
        if( bp::override func_setMargin = this->get_override( "setMargin" ) )
            func_setMargin( boost::ref(margin) );
        else{
            this->CEGUI::Window::setMargin( boost::ref(margin) );
        }
    }
    
    void default_setMargin( ::CEGUI::UBox const & margin ) {
        CEGUI::Window::setMargin( boost::ref(margin) );
    }

    virtual void setName( ::CEGUI::String const & name ) {
        if( bp::override func_setName = this->get_override( "setName" ) )
            func_setName( boost::ref(name) );
        else{
            this->CEGUI::NamedElement::setName( boost::ref(name) );
        }
    }
    
    void default_setName( ::CEGUI::String const & name ) {
        CEGUI::NamedElement::setName( boost::ref(name) );
    }

    virtual void setParent( ::CEGUI::Element * parent ){
        if( bp::override func_setParent = this->get_override( "setParent" ) )
            func_setParent( boost::python::ptr(parent) );
        else{
            this->CEGUI::Window::setParent( boost::python::ptr(parent) );
        }
    }
    
    virtual void default_setParent( ::CEGUI::Element * parent ){
        CEGUI::Window::setParent( boost::python::ptr(parent) );
    }

    virtual void setVerticalAlignment( ::CEGUI::VerticalAlignment const alignment ) {
        if( bp::override func_setVerticalAlignment = this->get_override( "setVerticalAlignment" ) )
            func_setVerticalAlignment( alignment );
        else{
            this->CEGUI::Element::setVerticalAlignment( alignment );
        }
    }
    
    void default_setVerticalAlignment( ::CEGUI::VerticalAlignment const alignment ) {
        CEGUI::Element::setVerticalAlignment( alignment );
    }

    virtual ::CEGUI::RefCounted< CEGUI::BoundSlot > subscribeScriptedEvent( ::CEGUI::String const & name, ::CEGUI::String const & subscriber_name ) {
        if( bp::override func_subscribeScriptedEvent = this->get_override( "subscribeScriptedEvent" ) )
            return func_subscribeScriptedEvent( boost::ref(name), boost::ref(subscriber_name) );
        else{
            return this->CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), boost::ref(subscriber_name) );
        }
    }
    
    ::CEGUI::RefCounted< CEGUI::BoundSlot > default_subscribeScriptedEvent( ::CEGUI::String const & name, ::CEGUI::String const & subscriber_name ) {
        return CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), boost::ref(subscriber_name) );
    }

    virtual ::CEGUI::RefCounted< CEGUI::BoundSlot > subscribeScriptedEvent( ::CEGUI::String const & name, unsigned int group, ::CEGUI::String const & subscriber_name ) {
        if( bp::override func_subscribeScriptedEvent = this->get_override( "subscribeScriptedEvent" ) )
            return func_subscribeScriptedEvent( boost::ref(name), group, boost::ref(subscriber_name) );
        else{
            return this->CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), group, boost::ref(subscriber_name) );
        }
    }
    
    ::CEGUI::RefCounted< CEGUI::BoundSlot > default_subscribeScriptedEvent( ::CEGUI::String const & name, unsigned int group, ::CEGUI::String const & subscriber_name ) {
        return CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), group, boost::ref(subscriber_name) );
    }

    void transferChildSurfaces(  ){
        CEGUI::Window::transferChildSurfaces(  );
    }

    virtual void update( float elapsed ) {
        if( bp::override func_update = this->get_override( "update" ) )
            func_update( elapsed );
        else{
            this->CEGUI::Window::update( elapsed );
        }
    }
    
    void default_update( float elapsed ) {
        CEGUI::Window::update( elapsed );
    }

    void updateGeometryRenderSettings(  ){
        CEGUI::Window::updateGeometryRenderSettings(  );
    }

    virtual void updateSelf( float elapsed ){
        if( bp::override func_updateSelf = this->get_override( "updateSelf" ) )
            func_updateSelf( elapsed );
        else{
            this->CEGUI::Window::updateSelf( elapsed );
        }
    }
    
    virtual void default_updateSelf( float elapsed ){
        CEGUI::Window::updateSelf( elapsed );
    }

    virtual bool validateWindowRenderer( ::CEGUI::WindowRenderer const * renderer ) const {
        if( bp::override func_validateWindowRenderer = this->get_override( "validateWindowRenderer" ) )
            return func_validateWindowRenderer( boost::python::ptr(renderer) );
        else{
            return this->CEGUI::Window::validateWindowRenderer( boost::python::ptr(renderer) );
        }
    }
    
    virtual bool default_validateWindowRenderer( ::CEGUI::WindowRenderer const * renderer ) const {
        return CEGUI::Window::validateWindowRenderer( boost::python::ptr(renderer) );
    }

    virtual bool writeAutoChildWindowXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        if( bp::override func_writeAutoChildWindowXML = this->get_override( "writeAutoChildWindowXML" ) )
            return func_writeAutoChildWindowXML( boost::ref(xml_stream) );
        else{
            return this->CEGUI::Window::writeAutoChildWindowXML( boost::ref(xml_stream) );
        }
    }
    
    virtual bool default_writeAutoChildWindowXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        return CEGUI::Window::writeAutoChildWindowXML( boost::ref(xml_stream) );
    }

    virtual int writeChildWindowsXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        if( bp::override func_writeChildWindowsXML = this->get_override( "writeChildWindowsXML" ) )
            return func_writeChildWindowsXML( boost::ref(xml_stream) );
        else{
            return this->CEGUI::Window::writeChildWindowsXML( boost::ref(xml_stream) );
        }
    }
    
    virtual int default_writeChildWindowsXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        return CEGUI::Window::writeChildWindowsXML( boost::ref(xml_stream) );
    }

    virtual int writePropertiesXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        if( bp::override func_writePropertiesXML = this->get_override( "writePropertiesXML" ) )
            return func_writePropertiesXML( boost::ref(xml_stream) );
        else{
            return this->CEGUI::Window::writePropertiesXML( boost::ref(xml_stream) );
        }
    }
    
    virtual int default_writePropertiesXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        return CEGUI::Window::writePropertiesXML( boost::ref(xml_stream) );
    }

    virtual void writeXMLToStream( ::CEGUI::XMLSerializer & xml_stream ) const  {
        if( bp::override func_writeXMLToStream = this->get_override( "writeXMLToStream" ) )
            func_writeXMLToStream( boost::ref(xml_stream) );
        else{
            this->CEGUI::Window::writeXMLToStream( boost::ref(xml_stream) );
        }
    }
    
    void default_writeXMLToStream( ::CEGUI::XMLSerializer & xml_stream ) const  {
        CEGUI::Window::writeXMLToStream( boost::ref(xml_stream) );
    }

};

void register_FrameWindow_class(){

    { //::CEGUI::FrameWindow
        typedef bp::class_< FrameWindow_wrapper, bp::bases< CEGUI::Window >, boost::noncopyable > FrameWindow_exposer_t;
        FrameWindow_exposer_t FrameWindow_exposer = FrameWindow_exposer_t( "FrameWindow", "*!\n\
        \n\
           Abstract base class for a movable, sizable, window with a title-bar and a frame.\n\
        *\n", bp::init< CEGUI::String const &, CEGUI::String const & >(( bp::arg("type"), bp::arg("name") ), "*************************************************************************\n\
           Construction  Destruction\n\
        *************************************************************************\n\
        *!\n\
        \n\
           Constructor for FrameWindow objects.\n\
        *\n") );
        bp::scope FrameWindow_scope( FrameWindow_exposer );
        bp::enum_< CEGUI::FrameWindow::SizingLocation>("SizingLocation")
            .value("SizingNone", CEGUI::FrameWindow::SizingNone)
            .value("SizingTopLeft", CEGUI::FrameWindow::SizingTopLeft)
            .value("SizingTopRight", CEGUI::FrameWindow::SizingTopRight)
            .value("SizingBottomLeft", CEGUI::FrameWindow::SizingBottomLeft)
            .value("SizingBottomRight", CEGUI::FrameWindow::SizingBottomRight)
            .value("SizingTop", CEGUI::FrameWindow::SizingTop)
            .value("SizingLeft", CEGUI::FrameWindow::SizingLeft)
            .value("SizingBottom", CEGUI::FrameWindow::SizingBottom)
            .value("SizingRight", CEGUI::FrameWindow::SizingRight)
            .export_values()
            ;
        { //::CEGUI::FrameWindow::closeClickHandler
        
            typedef bool ( FrameWindow_wrapper::*closeClickHandler_function_type )( ::CEGUI::EventArgs const & ) ;
            
            FrameWindow_exposer.def( 
                "closeClickHandler"
                , closeClickHandler_function_type( &FrameWindow_wrapper::closeClickHandler )
                , ( bp::arg("e") )
                , "*!\n\
            \n\
               Method to respond to close button click events and fire our close event\n\
            *\n" );
        
        }
        { //::CEGUI::FrameWindow::getCloseButton
        
            typedef ::CEGUI::PushButton * ( ::CEGUI::FrameWindow::*getCloseButton_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getCloseButton"
                , getCloseButton_function_type( &::CEGUI::FrameWindow::getCloseButton )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
                \n\
                    Return a pointer to the close button component widget for this\n\
                    FrameWindow.\n\
            \n\
                @return\n\
                    Pointer to a PushButton object.\n\
            \n\
                @exception UnknownObjectException\n\
                    Thrown if the close button component does not exist.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::getEWSizingCursorImage
        
            typedef ::CEGUI::Image const * ( ::CEGUI::FrameWindow::*getEWSizingCursorImage_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getEWSizingCursorImage"
                , getEWSizingCursorImage_function_type( &::CEGUI::FrameWindow::getEWSizingCursorImage )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
                \n\
                    Return a pointer to the currently set Image to be used for the east-west\n\
                    sizing mouse cursor.\n\
            \n\
                @return\n\
                    Pointer to an Image object, or 0 for none.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::getNESWSizingCursorImage
        
            typedef ::CEGUI::Image const * ( ::CEGUI::FrameWindow::*getNESWSizingCursorImage_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getNESWSizingCursorImage"
                , getNESWSizingCursorImage_function_type( &::CEGUI::FrameWindow::getNESWSizingCursorImage )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
                \n\
                    Return a pointer to the currently set Image to be used for the northeast-southwest\n\
                    sizing mouse cursor.\n\
            \n\
                @return\n\
                    Pointer to an Image object, or 0 for none.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::getNSSizingCursorImage
        
            typedef ::CEGUI::Image const * ( ::CEGUI::FrameWindow::*getNSSizingCursorImage_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getNSSizingCursorImage"
                , getNSSizingCursorImage_function_type( &::CEGUI::FrameWindow::getNSSizingCursorImage )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
                \n\
                    Return a pointer to the currently set Image to be used for the north-south\n\
                    sizing mouse cursor.\n\
            \n\
                @return\n\
                    Pointer to an Image object, or 0 for none.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::getNWSESizingCursorImage
        
            typedef ::CEGUI::Image const * ( ::CEGUI::FrameWindow::*getNWSESizingCursorImage_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getNWSESizingCursorImage"
                , getNWSESizingCursorImage_function_type( &::CEGUI::FrameWindow::getNWSESizingCursorImage )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
                \n\
                    Return a pointer to the currently set Image to be used for the northwest-southeast\n\
                    sizing mouse cursor.\n\
            \n\
                @return\n\
                    Pointer to an Image object, or 0 for none.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::getSizingBorderAtPoint
        
            typedef ::CEGUI::FrameWindow::SizingLocation ( FrameWindow_wrapper::*getSizingBorderAtPoint_function_type )( ::CEGUI::Vector2f const & ) const;
            
            FrameWindow_exposer.def( 
                "getSizingBorderAtPoint"
                , getSizingBorderAtPoint_function_type( &FrameWindow_wrapper::getSizingBorderAtPoint )
                , ( bp::arg("pt") )
                , "*!\n\
               \n\
                  check local pixel co-ordinate point 'pt' and return one of the\n\
                  SizingLocation enumerated values depending where the point falls on\n\
                  the sizing border.\n\
            \n\
               @param pt\n\
                  Point object describing, in pixels, the window relative offset to check.\n\
            \n\
               @return\n\
                  One of the SizingLocation enumerated values that describe which part of\n\
                  the sizing border that  pt corresponded to, if any.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::getSizingBorderThickness
        
            typedef float ( ::CEGUI::FrameWindow::*getSizingBorderThickness_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getSizingBorderThickness"
                , getSizingBorderThickness_function_type( &::CEGUI::FrameWindow::getSizingBorderThickness )
                , "*!\n\
               \n\
                  Return the thickness of the sizing border.\n\
            \n\
               @return\n\
                  float value describing the thickness of the sizing border in screen pixels.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::getSizingRect
        
            typedef ::CEGUI::Rectf ( FrameWindow_wrapper::*getSizingRect_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getSizingRect"
                , getSizingRect_function_type( &FrameWindow_wrapper::default_getSizingRect )
                , "*!\n\
            \n\
               Return a Rect that describes, in window relative pixel co-ordinates, the outer edge of the sizing\
               area for this window.\n\
            *\n" );
        
        }
        { //::CEGUI::FrameWindow::getTitlebar
        
            typedef ::CEGUI::Titlebar * ( ::CEGUI::FrameWindow::*getTitlebar_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getTitlebar"
                , getTitlebar_function_type( &::CEGUI::FrameWindow::getTitlebar )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
                \n\
                    Return a pointer to the Titlebar component widget for this FrameWindow.\n\
            \n\
                @return\n\
                    Pointer to a Titlebar object.\n\
            \n\
                @exception UnknownObjectException\n\
                    Thrown if the Titlebar component does not exist.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::initialiseComponents
        
            typedef void ( ::CEGUI::FrameWindow::*initialiseComponents_function_type )(  ) ;
            typedef void ( FrameWindow_wrapper::*default_initialiseComponents_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "initialiseComponents"
                , initialiseComponents_function_type(&::CEGUI::FrameWindow::initialiseComponents)
                , default_initialiseComponents_function_type(&FrameWindow_wrapper::default_initialiseComponents) );
        
        }
        { //::CEGUI::FrameWindow::isBottomSizingLocation
        
            typedef bool ( FrameWindow_wrapper::*isBottomSizingLocation_function_type )( ::CEGUI::FrameWindow::SizingLocation ) const;
            
            FrameWindow_exposer.def( 
                "isBottomSizingLocation"
                , isBottomSizingLocation_function_type( &FrameWindow_wrapper::isBottomSizingLocation )
                , ( bp::arg("loc") )
                , "*!\n\
               \n\
                  return true if given SizingLocation is on bottom edge.\n\
            \n\
               @param loc\n\
                  SizingLocation value to be checked.\n\
            \n\
               @return\n\
                  true if  loc is on the bottom edge.  false if  loc is not on the bottom edge.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::isCloseButtonEnabled
        
            typedef bool ( ::CEGUI::FrameWindow::*isCloseButtonEnabled_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "isCloseButtonEnabled"
                , isCloseButtonEnabled_function_type( &::CEGUI::FrameWindow::isCloseButtonEnabled )
                , "*!\n\
               \n\
                  Return whether this close button for this window is enabled.\n\
            \n\
               @return\n\
                  true if the window has a close button and it is enabled, false if the window either has no\
                  close button or if the close button is disabled.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::isDragMovingEnabled
        
            typedef bool ( ::CEGUI::FrameWindow::*isDragMovingEnabled_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "isDragMovingEnabled"
                , isDragMovingEnabled_function_type( &::CEGUI::FrameWindow::isDragMovingEnabled )
                , "*!\n\
               \n\
                  Return whether this FrameWindow can be moved by dragging the title bar.\n\
            \n\
               @return\n\
                  true if the Window will move when the user drags the title bar, false if the window will not\
                  move.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::isFrameEnabled
        
            typedef bool ( ::CEGUI::FrameWindow::*isFrameEnabled_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "isFrameEnabled"
                , isFrameEnabled_function_type( &::CEGUI::FrameWindow::isFrameEnabled )
                , "*!\n\
               \n\
                  Return whether the frame for this window is enabled.\n\
            \n\
               @return\n\
                  true if the frame for this window is enabled, false if the frame for this window is\
                  disabled.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::isHit
        
            typedef bool ( ::CEGUI::FrameWindow::*isHit_function_type )( ::CEGUI::Vector2f const &,bool const ) const;
            typedef bool ( FrameWindow_wrapper::*default_isHit_function_type )( ::CEGUI::Vector2f const &,bool const ) const;
            
            FrameWindow_exposer.def( 
                "isHit"
                , isHit_function_type(&::CEGUI::FrameWindow::isHit)
                , default_isHit_function_type(&FrameWindow_wrapper::default_isHit)
                , ( bp::arg("position"), bp::arg("arg1") ) );
        
        }
        { //::CEGUI::FrameWindow::isLeftSizingLocation
        
            typedef bool ( FrameWindow_wrapper::*isLeftSizingLocation_function_type )( ::CEGUI::FrameWindow::SizingLocation ) const;
            
            FrameWindow_exposer.def( 
                "isLeftSizingLocation"
                , isLeftSizingLocation_function_type( &FrameWindow_wrapper::isLeftSizingLocation )
                , ( bp::arg("loc") )
                , "*!\n\
               \n\
                  return true if given SizingLocation is on left edge.\n\
            \n\
               @param loc\n\
                  SizingLocation value to be checked.\n\
            \n\
               @return\n\
                  true if  loc is on the left edge.  false if  loc is not on the left edge.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::isRightSizingLocation
        
            typedef bool ( FrameWindow_wrapper::*isRightSizingLocation_function_type )( ::CEGUI::FrameWindow::SizingLocation ) const;
            
            FrameWindow_exposer.def( 
                "isRightSizingLocation"
                , isRightSizingLocation_function_type( &FrameWindow_wrapper::isRightSizingLocation )
                , ( bp::arg("loc") )
                , "*!\n\
               \n\
                  return true if given SizingLocation is on right edge.\n\
            \n\
               @param loc\n\
                  SizingLocation value to be checked.\n\
            \n\
               @return\n\
                  true if  loc is on the right edge.  false if  loc is not on the right edge.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::isRolledup
        
            typedef bool ( ::CEGUI::FrameWindow::*isRolledup_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "isRolledup"
                , isRolledup_function_type( &::CEGUI::FrameWindow::isRolledup )
                , "*!\n\
               \n\
                  Return whether the window is currently rolled up (a.k.a shaded).\n\
            \n\
               @return\n\
                  true if the window is rolled up, false if the window is not rolled up.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::isRollupEnabled
        
            typedef bool ( ::CEGUI::FrameWindow::*isRollupEnabled_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "isRollupEnabled"
                , isRollupEnabled_function_type( &::CEGUI::FrameWindow::isRollupEnabled )
                , "*!\n\
               \n\
                  Return whether roll up (a.k.a shading) is enabled for this window.\n\
            \n\
               @return\n\
                  true if roll up is enabled, false if roll up is disabled.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::isSizingEnabled
        
            typedef bool ( ::CEGUI::FrameWindow::*isSizingEnabled_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "isSizingEnabled"
                , isSizingEnabled_function_type( &::CEGUI::FrameWindow::isSizingEnabled )
                , "*!\n\
               \n\
                  Return whether this window is sizable.  Note that this requires that the window have an\
                  enabled frame and that sizing itself is enabled\n\
            \n\
               @return\n\
                  true if the window can be sized, false if the window can not be sized\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::isTitleBarEnabled
        
            typedef bool ( ::CEGUI::FrameWindow::*isTitleBarEnabled_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "isTitleBarEnabled"
                , isTitleBarEnabled_function_type( &::CEGUI::FrameWindow::isTitleBarEnabled )
                , "*!\n\
               \n\
                  Return whether the title bar for this window is enabled.\n\
            \n\
               @return\n\
                  true if the window has a title bar and it is enabled, false if the window has no title bar or\
                  if the title bar is disabled.\n\
               *  \n" );
        
        }
        { //::CEGUI::FrameWindow::isTopSizingLocation
        
            typedef bool ( FrameWindow_wrapper::*isTopSizingLocation_function_type )( ::CEGUI::FrameWindow::SizingLocation ) const;
            
            FrameWindow_exposer.def( 
                "isTopSizingLocation"
                , isTopSizingLocation_function_type( &FrameWindow_wrapper::isTopSizingLocation )
                , ( bp::arg("loc") )
                , "*!\n\
               \n\
                  return true if given SizingLocation is on top edge.\n\
            \n\
               @param loc\n\
                  SizingLocation value to be checked.\n\
            \n\
               @return\n\
                  true if  loc is on the top edge.  false if  loc is not on the top edge.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::moveBottomEdge
        
            typedef bool ( FrameWindow_wrapper::*moveBottomEdge_function_type )( float,::CEGUI::URect & ) ;
            
            FrameWindow_exposer.def( 
                "moveBottomEdge"
                , moveBottomEdge_function_type( &FrameWindow_wrapper::moveBottomEdge )
                , ( bp::arg("delta"), bp::arg("out_area") )
                , "*!\n\
               \n\
                  move the window's bottom edge by 'delta'.  The rest of the window does not move, thus this\
                  changes the size of the Window.\n\
            \n\
               @param delta\n\
                  float value that specifies the amount to move the window edge, and in which direction.\
                  Positive values make window larger.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::moveLeftEdge
        
            typedef bool ( FrameWindow_wrapper::*moveLeftEdge_function_type )( float,::CEGUI::URect & ) ;
            
            FrameWindow_exposer.def( 
                "moveLeftEdge"
                , moveLeftEdge_function_type( &FrameWindow_wrapper::moveLeftEdge )
                , ( bp::arg("delta"), bp::arg("out_area") )
                , "*************************************************************************\n\
                  Implementation Functions\n\
               *************************************************************************\n\
               *!\n\
               \n\
                  move the window's left edge by 'delta'.  The rest of the window does not move, thus this\
                  changes the size of the Window.\n\
            \n\
               @param delta\n\
                  float value that specifies the amount to move the window edge, and in which direction.\
                  Positive values make window smaller.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::moveRightEdge
        
            typedef bool ( FrameWindow_wrapper::*moveRightEdge_function_type )( float,::CEGUI::URect & ) ;
            
            FrameWindow_exposer.def( 
                "moveRightEdge"
                , moveRightEdge_function_type( &FrameWindow_wrapper::moveRightEdge )
                , ( bp::arg("delta"), bp::arg("out_area") )
                , "*!\n\
               \n\
                  move the window's right edge by 'delta'.  The rest of the window does not move, thus this\
                  changes the size of the Window.\n\
            \n\
               @param delta\n\
                  float value that specifies the amount to move the window edge, and in which direction.\
                  Positive values make window larger.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::moveTopEdge
        
            typedef bool ( FrameWindow_wrapper::*moveTopEdge_function_type )( float,::CEGUI::URect & ) ;
            
            FrameWindow_exposer.def( 
                "moveTopEdge"
                , moveTopEdge_function_type( &FrameWindow_wrapper::moveTopEdge )
                , ( bp::arg("delta"), bp::arg("out_area") )
                , "*!\n\
               \n\
                  move the window's top edge by 'delta'.  The rest of the window does not move, thus this\
                  changes the size of the Window.\n\
            \n\
               @param delta\n\
                  float value that specifies the amount to move the window edge, and in which direction.\
                  Positive values make window smaller.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::offsetPixelPosition
        
            typedef void ( ::CEGUI::FrameWindow::*offsetPixelPosition_function_type )( ::CEGUI::Vector2f const & ) ;
            
            FrameWindow_exposer.def( 
                "offsetPixelPosition"
                , offsetPixelPosition_function_type( &::CEGUI::FrameWindow::offsetPixelPosition )
                , ( bp::arg("offset") )
                , "*!\n\
               \n\
                  Move the window by the pixel offsets specified in  offset.\n\
            \n\
                  This is intended for internal system use - it is the method by which the title bar moves the\
                  frame window.\n\
            \n\
               @param offset\n\
                  Vector2 object containing the offsets to apply (offsets are in screen pixels).\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::onActivated
        
            typedef void ( FrameWindow_wrapper::*onActivated_function_type )( ::CEGUI::ActivationEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onActivated"
                , onActivated_function_type( &FrameWindow_wrapper::default_onActivated )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::FrameWindow::onCaptureLost
        
            typedef void ( FrameWindow_wrapper::*onCaptureLost_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onCaptureLost"
                , onCaptureLost_function_type( &FrameWindow_wrapper::default_onCaptureLost )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::FrameWindow::onCloseClicked
        
            typedef void ( FrameWindow_wrapper::*onCloseClicked_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onCloseClicked"
                , onCloseClicked_function_type( &FrameWindow_wrapper::default_onCloseClicked )
                , ( bp::arg("e") )
                , "*!\n\
            \n\
               Event generated internally whenever the close button is clicked.\n\
            *\n" );
        
        }
        { //::CEGUI::FrameWindow::onDeactivated
        
            typedef void ( FrameWindow_wrapper::*onDeactivated_function_type )( ::CEGUI::ActivationEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onDeactivated"
                , onDeactivated_function_type( &FrameWindow_wrapper::default_onDeactivated )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::FrameWindow::onDragSizingEnded
        
            typedef void ( FrameWindow_wrapper::*onDragSizingEnded_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onDragSizingEnded"
                , onDragSizingEnded_function_type( &FrameWindow_wrapper::default_onDragSizingEnded )
                , ( bp::arg("e") )
                , "! Handler called when drag-sizing of the FrameWindow ends.\n" );
        
        }
        { //::CEGUI::FrameWindow::onDragSizingStarted
        
            typedef void ( FrameWindow_wrapper::*onDragSizingStarted_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onDragSizingStarted"
                , onDragSizingStarted_function_type( &FrameWindow_wrapper::default_onDragSizingStarted )
                , ( bp::arg("e") )
                , "! Handler called when drag-sizing of the FrameWindow starts.\n" );
        
        }
        { //::CEGUI::FrameWindow::onMouseButtonDown
        
            typedef void ( FrameWindow_wrapper::*onMouseButtonDown_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMouseButtonDown"
                , onMouseButtonDown_function_type( &FrameWindow_wrapper::default_onMouseButtonDown )
                , ( bp::arg("e") )
                , "*************************************************************************\n\
               Overridden event handlers\n\
            *************************************************************************\n" );
        
        }
        { //::CEGUI::FrameWindow::onMouseButtonUp
        
            typedef void ( FrameWindow_wrapper::*onMouseButtonUp_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMouseButtonUp"
                , onMouseButtonUp_function_type( &FrameWindow_wrapper::default_onMouseButtonUp )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::FrameWindow::onMouseMove
        
            typedef void ( FrameWindow_wrapper::*onMouseMove_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMouseMove"
                , onMouseMove_function_type( &FrameWindow_wrapper::default_onMouseMove )
                , ( bp::arg("e") )
                , "*************************************************************************\n\
               Overridden event handlers\n\
            *************************************************************************\n" );
        
        }
        { //::CEGUI::FrameWindow::onRollupToggled
        
            typedef void ( FrameWindow_wrapper::*onRollupToggled_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onRollupToggled"
                , onRollupToggled_function_type( &FrameWindow_wrapper::default_onRollupToggled )
                , ( bp::arg("e") )
                , "*************************************************************************\n\
               New events for Frame Windows\n\
            *************************************************************************\n\
            *!\n\
            \n\
               Event generated internally whenever the roll-up  shade state of the window\n\
               changes.\n\
            *\n" );
        
        }
        { //::CEGUI::FrameWindow::onTextChanged
        
            typedef void ( FrameWindow_wrapper::*onTextChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onTextChanged"
                , onTextChanged_function_type( &FrameWindow_wrapper::default_onTextChanged )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::FrameWindow::setCloseButtonEnabled
        
            typedef void ( ::CEGUI::FrameWindow::*setCloseButtonEnabled_function_type )( bool ) ;
            
            FrameWindow_exposer.def( 
                "setCloseButtonEnabled"
                , setCloseButtonEnabled_function_type( &::CEGUI::FrameWindow::setCloseButtonEnabled )
                , ( bp::arg("setting") )
                , "*!\n\
               \n\
                  Enables or disables the close button for the frame window.\n\
            \n\
               @param setting\n\
                  Set to true to enable the close button (if one is attached), or false to disable the close\
                  button.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::setCursorForPoint
        
            typedef void ( FrameWindow_wrapper::*setCursorForPoint_function_type )( ::CEGUI::Vector2f const & ) const;
            
            FrameWindow_exposer.def( 
                "setCursorForPoint"
                , setCursorForPoint_function_type( &FrameWindow_wrapper::setCursorForPoint )
                , ( bp::arg("pt") )
                , "*!\n\
            \n\
               Set the appropriate mouse cursor for the given window-relative pixel point.\n\
            *\n" );
        
        }
        { //::CEGUI::FrameWindow::setDragMovingEnabled
        
            typedef void ( ::CEGUI::FrameWindow::*setDragMovingEnabled_function_type )( bool ) ;
            
            FrameWindow_exposer.def( 
                "setDragMovingEnabled"
                , setDragMovingEnabled_function_type( &::CEGUI::FrameWindow::setDragMovingEnabled )
                , ( bp::arg("setting") )
                , "*!\n\
               \n\
                  Set whether this FrameWindow can be moved by dragging the title bar.\n\
            \n\
               @param setting\n\
                  true if the Window should move when the user drags the title bar, false if the window should\
                  not move.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::setEWSizingCursorImage
        
            typedef void ( ::CEGUI::FrameWindow::*setEWSizingCursorImage_function_type )( ::CEGUI::Image const * ) ;
            
            FrameWindow_exposer.def( 
                "setEWSizingCursorImage"
                , setEWSizingCursorImage_function_type( &::CEGUI::FrameWindow::setEWSizingCursorImage )
                , ( bp::arg("image") )
                , "*!\n\
                \n\
                    Set the Image to be used for the east-west sizing mouse cursor.\n\
            \n\
                @param image\n\
                    Pointer to an Image object, or 0 for none.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::setEWSizingCursorImage
        
            typedef void ( ::CEGUI::FrameWindow::*setEWSizingCursorImage_function_type )( ::CEGUI::String const & ) ;
            
            FrameWindow_exposer.def( 
                "setEWSizingCursorImage"
                , setEWSizingCursorImage_function_type( &::CEGUI::FrameWindow::setEWSizingCursorImage )
                , ( bp::arg("name") )
                , "*!\n\
                \n\
                    Set the image to be used for the east-west sizing mouse cursor.\n\
            \n\
                @param name\n\
                    String holding the name of the Image to be used.\n\
            \n\
                @return\n\
                    Nothing.\n\
            \n\
                @exception UnknownObjectException thrown if either  imageset or  image refer to non-existant\
                entities.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::setFrameEnabled
        
            typedef void ( ::CEGUI::FrameWindow::*setFrameEnabled_function_type )( bool ) ;
            
            FrameWindow_exposer.def( 
                "setFrameEnabled"
                , setFrameEnabled_function_type( &::CEGUI::FrameWindow::setFrameEnabled )
                , ( bp::arg("setting") )
                , "*!\n\
               \n\
                  Enables or disables the frame for this window.\n\
            \n\
               @param setting\n\
                  set to true to enable the frame for this window, or false to disable the frame for this\
                  window.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::setNESWSizingCursorImage
        
            typedef void ( ::CEGUI::FrameWindow::*setNESWSizingCursorImage_function_type )( ::CEGUI::Image const * ) ;
            
            FrameWindow_exposer.def( 
                "setNESWSizingCursorImage"
                , setNESWSizingCursorImage_function_type( &::CEGUI::FrameWindow::setNESWSizingCursorImage )
                , ( bp::arg("image") )
                , "*!\n\
                \n\
                    Set the Image to be used for the northeast-southwest sizing mouse cursor.\n\
            \n\
                @param image\n\
                    Pointer to an Image object, or 0 for none.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::setNESWSizingCursorImage
        
            typedef void ( ::CEGUI::FrameWindow::*setNESWSizingCursorImage_function_type )( ::CEGUI::String const & ) ;
            
            FrameWindow_exposer.def( 
                "setNESWSizingCursorImage"
                , setNESWSizingCursorImage_function_type( &::CEGUI::FrameWindow::setNESWSizingCursorImage )
                , ( bp::arg("name") )
                , "*!\n\
                \n\
                    Set the image to be used for the northeast-southwest sizing mouse cursor.\n\
            \n\
                @param name\n\
                    String holding the name of the Image to be used.\n\
            \n\
                @return\n\
                    Nothing.\n\
            \n\
                @exception UnknownObjectException thrown if either  imageset or  image refer to non-existant\
                entities.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::setNSSizingCursorImage
        
            typedef void ( ::CEGUI::FrameWindow::*setNSSizingCursorImage_function_type )( ::CEGUI::Image const * ) ;
            
            FrameWindow_exposer.def( 
                "setNSSizingCursorImage"
                , setNSSizingCursorImage_function_type( &::CEGUI::FrameWindow::setNSSizingCursorImage )
                , ( bp::arg("image") )
                , "*!\n\
                \n\
                    Set the Image to be used for the north-south sizing mouse cursor.\n\
            \n\
                @param image\n\
                    Pointer to an Image object, or 0 for none.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::setNSSizingCursorImage
        
            typedef void ( ::CEGUI::FrameWindow::*setNSSizingCursorImage_function_type )( ::CEGUI::String const & ) ;
            
            FrameWindow_exposer.def( 
                "setNSSizingCursorImage"
                , setNSSizingCursorImage_function_type( &::CEGUI::FrameWindow::setNSSizingCursorImage )
                , ( bp::arg("name") )
                , "*!\n\
                \n\
                    Set the image to be used for the north-south sizing mouse cursor.\n\
            \n\
                @param name\n\
                    String holding the name of the Image to be used.\n\
            \n\
                @return\n\
                    Nothing.\n\
            \n\
                @exception UnknownObjectException thrown if either  imageset or  image refer to non-existant\
                entities.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::setNWSESizingCursorImage
        
            typedef void ( ::CEGUI::FrameWindow::*setNWSESizingCursorImage_function_type )( ::CEGUI::Image const * ) ;
            
            FrameWindow_exposer.def( 
                "setNWSESizingCursorImage"
                , setNWSESizingCursorImage_function_type( &::CEGUI::FrameWindow::setNWSESizingCursorImage )
                , ( bp::arg("image") )
                , "*!\n\
                \n\
                    Set the Image to be used for the northwest-southeast sizing mouse cursor.\n\
            \n\
                @param image\n\
                    Pointer to an Image object, or 0 for none.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::setNWSESizingCursorImage
        
            typedef void ( ::CEGUI::FrameWindow::*setNWSESizingCursorImage_function_type )( ::CEGUI::String const & ) ;
            
            FrameWindow_exposer.def( 
                "setNWSESizingCursorImage"
                , setNWSESizingCursorImage_function_type( &::CEGUI::FrameWindow::setNWSESizingCursorImage )
                , ( bp::arg("name") )
                , "*!\n\
                \n\
                    Set the image to be used for the northwest-southeast sizing mouse cursor.\n\
            \n\
                @param name\n\
                    String holding the name of the Image to be used.\n\
            \n\
                @return\n\
                    Nothing.\n\
            \n\
                @exception UnknownObjectException thrown if either  imageset or  image refer to non-existant\
                entities.\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::setRolledup
        
            typedef void ( ::CEGUI::FrameWindow::*setRolledup_function_type )( bool ) ;
            
            FrameWindow_exposer.def( 
                "setRolledup"
                , setRolledup_function_type( &::CEGUI::FrameWindow::setRolledup )
                , ( bp::arg("val") )
                , "*!\n\
                \n\
                    Sets whether the window is currently rolled up (a.k.a shaded).\n\
            \n\
                @see\n\
                    Window.isRolledup\n\
                *\n" );
        
        }
        { //::CEGUI::FrameWindow::setRollupEnabled
        
            typedef void ( ::CEGUI::FrameWindow::*setRollupEnabled_function_type )( bool ) ;
            
            FrameWindow_exposer.def( 
                "setRollupEnabled"
                , setRollupEnabled_function_type( &::CEGUI::FrameWindow::setRollupEnabled )
                , ( bp::arg("setting") )
                , "*!\n\
               \n\
                  Enables or disables roll-up (shading) for this window.\n\
            \n\
               @param setting\n\
                  Set to true to enable roll-up for the frame window, or false to disable roll-up.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::setSizingBorderThickness
        
            typedef void ( ::CEGUI::FrameWindow::*setSizingBorderThickness_function_type )( float ) ;
            
            FrameWindow_exposer.def( 
                "setSizingBorderThickness"
                , setSizingBorderThickness_function_type( &::CEGUI::FrameWindow::setSizingBorderThickness )
                , ( bp::arg("pixels") )
                , "*!\n\
               \n\
                  Set the size of the sizing border for this window.\n\
            \n\
               @param pixels\n\
                  float value specifying the thickness for the sizing border in screen pixels.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::setSizingEnabled
        
            typedef void ( ::CEGUI::FrameWindow::*setSizingEnabled_function_type )( bool ) ;
            
            FrameWindow_exposer.def( 
                "setSizingEnabled"
                , setSizingEnabled_function_type( &::CEGUI::FrameWindow::setSizingEnabled )
                , ( bp::arg("setting") )
                , "*!\n\
               \n\
                  Enables or disables sizing for this window.\n\
            \n\
               @param setting\n\
                  set to true to enable sizing (also requires frame to be enabled), or false to disable\
                  sizing.\n\
            \n\
               @return\n\
                  nothing\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::setTitleBarEnabled
        
            typedef void ( ::CEGUI::FrameWindow::*setTitleBarEnabled_function_type )( bool ) ;
            
            FrameWindow_exposer.def( 
                "setTitleBarEnabled"
                , setTitleBarEnabled_function_type( &::CEGUI::FrameWindow::setTitleBarEnabled )
                , ( bp::arg("setting") )
                , "*!\n\
               \n\
                  Enables or disables the title bar for the frame window.\n\
            \n\
               @param setting\n\
                  set to true to enable the title bar (if one is attached), or false to disable the title bar.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::FrameWindow::toggleRollup
        
            typedef void ( ::CEGUI::FrameWindow::*toggleRollup_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "toggleRollup"
                , toggleRollup_function_type( &::CEGUI::FrameWindow::toggleRollup )
                , "*!\n\
               \n\
                  Toggles the state of the window between rolled-up (shaded) and normal sizes.  This requires\
                  roll-up to be enabled.\n\
            \n\
               @return\n\
                  Nothing\n\
               *\n" );
        
        }
        FrameWindow_exposer.add_static_property( "CloseButtonName"
                        , bp::make_getter( &CEGUI::FrameWindow::CloseButtonName
                                , bp::return_value_policy< bp::return_by_value >() ) );
        FrameWindow_exposer.def_readonly( "DefaultSizingBorderSize", CEGUI::FrameWindow::DefaultSizingBorderSize, "other bits\n" );
        FrameWindow_exposer.add_static_property( "EventCloseClicked"
                        , bp::make_getter( &CEGUI::FrameWindow::EventCloseClicked
                                , bp::return_value_policy< bp::return_by_value >() ) );
        FrameWindow_exposer.add_static_property( "EventDragSizingEnded"
                        , bp::make_getter( &CEGUI::FrameWindow::EventDragSizingEnded
                                , bp::return_value_policy< bp::return_by_value >() ) );
        FrameWindow_exposer.add_static_property( "EventDragSizingStarted"
                        , bp::make_getter( &CEGUI::FrameWindow::EventDragSizingStarted
                                , bp::return_value_policy< bp::return_by_value >() ) );
        FrameWindow_exposer.add_static_property( "EventRollupToggled"
                        , bp::make_getter( &CEGUI::FrameWindow::EventRollupToggled
                                , bp::return_value_policy< bp::return_by_value >() ) );
        FrameWindow_exposer.add_static_property( "TitlebarName"
                        , bp::make_getter( &CEGUI::FrameWindow::TitlebarName
                                , bp::return_value_policy< bp::return_by_value >() ) );
        { //::CEGUI::Window::addChild_impl
        
            typedef void ( FrameWindow_wrapper::*addChild_impl_function_type )( ::CEGUI::Element * ) ;
            
            FrameWindow_exposer.def( 
                "addChild_impl"
                , addChild_impl_function_type( &FrameWindow_wrapper::default_addChild_impl )
                , ( bp::arg("element") )
                , "*!\n\
            opydoc Element.addChild_impl\n\
            *\n" );
        
        }
        { //::CEGUI::Element::addElementProperties
        
            typedef void ( FrameWindow_wrapper::*addElementProperties_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "addElementProperties"
                , addElementProperties_function_type( &FrameWindow_wrapper::addElementProperties )
                , "*!\n\
            \n\
                Add standard CEGUI.Element properties.\n\
            *\n" );
        
        }
        { //::CEGUI::NamedElement::addNamedElementProperties
        
            typedef void ( FrameWindow_wrapper::*addNamedElementProperties_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "addNamedElementProperties"
                , addNamedElementProperties_function_type( &FrameWindow_wrapper::addNamedElementProperties )
                , "*!\n\
             Add standard CEGUI.NamedElement properties.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::addWindowProperties
        
            typedef void ( FrameWindow_wrapper::*addWindowProperties_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "addWindowProperties"
                , addWindowProperties_function_type( &FrameWindow_wrapper::addWindowProperties )
                , "*!\n\
            \n\
                Add standard CEGUI.Window properties.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::addWindowToDrawList
        
            typedef void ( FrameWindow_wrapper::*addWindowToDrawList_function_type )( ::CEGUI::Window &,bool ) ;
            
            FrameWindow_exposer.def( 
                "addWindowToDrawList"
                , addWindowToDrawList_function_type( &FrameWindow_wrapper::addWindowToDrawList )
                , ( bp::arg("wnd"), bp::arg("at_back")=(bool)(false) )
                , "*!\n\
                \n\
                    Add the given window to the drawing list at an appropriate position for\n\
                    it's settings and the required direction.  Basically, when  at_back\n\
                    is false, the window will appear in front of all other windows with the\n\
                    same 'always on top' setting.  When  at_back is true, the window will\n\
                    appear behind all other windows wih the same 'always on top' setting.\n\
            \n\
                @param wnd\n\
                    Window object to be added to the drawing list.\n\
            \n\
                @param at_back\n\
                    Indicates whether the window should be placed at the back of other\n\
                    windows in the same group. If this is false, the window is placed in\n\
                    front of other windows in the group.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::allocateRenderingWindow
        
            typedef void ( FrameWindow_wrapper::*allocateRenderingWindow_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "allocateRenderingWindow"
                , allocateRenderingWindow_function_type( &FrameWindow_wrapper::allocateRenderingWindow )
                , "! helper to create and setup the auto RenderingWindow surface\n" );
        
        }
        { //::CEGUI::Window::banPropertiesForAutoWindow
        
            typedef void ( FrameWindow_wrapper::*banPropertiesForAutoWindow_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "banPropertiesForAutoWindow"
                , banPropertiesForAutoWindow_function_type( &FrameWindow_wrapper::default_banPropertiesForAutoWindow ) );
        
        }
        { //::CEGUI::Window::beginInitialisation
        
            typedef void ( ::CEGUI::Window::*beginInitialisation_function_type )(  ) ;
            typedef void ( FrameWindow_wrapper::*default_beginInitialisation_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "beginInitialisation"
                , beginInitialisation_function_type(&::CEGUI::Window::beginInitialisation)
                , default_beginInitialisation_function_type(&FrameWindow_wrapper::default_beginInitialisation) );
        
        }
        { //::CEGUI::Window::bufferGeometry
        
            typedef void ( FrameWindow_wrapper::*bufferGeometry_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            FrameWindow_exposer.def( 
                "bufferGeometry"
                , bufferGeometry_function_type( &FrameWindow_wrapper::bufferGeometry )
                , ( bp::arg("ctx") )
                , "*!\n\
                \n\
                    Perform drawing operations concerned with generating and buffering\n\
                    window geometry.\n\
            \n\
                \note\n\
                    This function is a sub-function of drawSelf; it is provided to make it\n\
                    easier to override drawSelf without needing to duplicate large sections\n\
                    of the code from the default implementation.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::cleanupChildren
        
            typedef void ( FrameWindow_wrapper::*cleanupChildren_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "cleanupChildren"
                , cleanupChildren_function_type( &FrameWindow_wrapper::default_cleanupChildren )
                , "*!\n\
            \n\
                Cleanup child windows\n\
            *\n" );
        
        }
        { //::CEGUI::Window::cloneChildWidgetsTo
        
            typedef void ( ::CEGUI::Window::*cloneChildWidgetsTo_function_type )( ::CEGUI::Window & ) const;
            typedef void ( FrameWindow_wrapper::*default_cloneChildWidgetsTo_function_type )( ::CEGUI::Window & ) const;
            
            FrameWindow_exposer.def( 
                "cloneChildWidgetsTo"
                , cloneChildWidgetsTo_function_type(&::CEGUI::Window::cloneChildWidgetsTo)
                , default_cloneChildWidgetsTo_function_type(&FrameWindow_wrapper::default_cloneChildWidgetsTo)
                , ( bp::arg("target") ) );
        
        }
        { //::CEGUI::Window::clonePropertiesTo
        
            typedef void ( ::CEGUI::Window::*clonePropertiesTo_function_type )( ::CEGUI::Window & ) const;
            typedef void ( FrameWindow_wrapper::*default_clonePropertiesTo_function_type )( ::CEGUI::Window & ) const;
            
            FrameWindow_exposer.def( 
                "clonePropertiesTo"
                , clonePropertiesTo_function_type(&::CEGUI::Window::clonePropertiesTo)
                , default_clonePropertiesTo_function_type(&FrameWindow_wrapper::default_clonePropertiesTo)
                , ( bp::arg("target") ) );
        
        }
        { //::CEGUI::Window::destroy
        
            typedef void ( ::CEGUI::Window::*destroy_function_type )(  ) ;
            typedef void ( FrameWindow_wrapper::*default_destroy_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "destroy"
                , destroy_function_type(&::CEGUI::Window::destroy)
                , default_destroy_function_type(&FrameWindow_wrapper::default_destroy) );
        
        }
        { //::CEGUI::Window::drawSelf
        
            typedef void ( FrameWindow_wrapper::*drawSelf_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            FrameWindow_exposer.def( 
                "drawSelf"
                , drawSelf_function_type( &FrameWindow_wrapper::default_drawSelf )
                , ( bp::arg("ctx") )
                , "*!\n\
                \n\
                    Perform the actual rendering for this Window.\n\
            \n\
                @param ctx\n\
                    RenderingContext holding the details of the RenderingSurface to be\n\
                    used for the Window rendering operations.\n\
            \n\
                @return\n\
                    Nothing\n\
                *\n" );
        
        }
        { //::CEGUI::Window::endInitialisation
        
            typedef void ( ::CEGUI::Window::*endInitialisation_function_type )(  ) ;
            typedef void ( FrameWindow_wrapper::*default_endInitialisation_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "endInitialisation"
                , endInitialisation_function_type(&::CEGUI::Window::endInitialisation)
                , default_endInitialisation_function_type(&FrameWindow_wrapper::default_endInitialisation) );
        
        }
        { //::CEGUI::Element::fireAreaChangeEvents
        
            typedef void ( FrameWindow_wrapper::*fireAreaChangeEvents_function_type )( bool const,bool const ) ;
            
            FrameWindow_exposer.def( 
                "fireAreaChangeEvents"
                , fireAreaChangeEvents_function_type( &FrameWindow_wrapper::fireAreaChangeEvents )
                , ( bp::arg("moved"), bp::arg("sized") )
                , "! helper to fire events based on changes to area rect\n" );
        
        }
        { //::CEGUI::EventSet::fireEvent
        
            typedef void ( ::CEGUI::EventSet::*fireEvent_function_type )( ::CEGUI::String const &,::CEGUI::EventArgs &,::CEGUI::String const & ) ;
            typedef void ( FrameWindow_wrapper::*default_fireEvent_function_type )( ::CEGUI::String const &,::CEGUI::EventArgs &,::CEGUI::String const & ) ;
            
            FrameWindow_exposer.def( 
                "fireEvent"
                , fireEvent_function_type(&::CEGUI::EventSet::fireEvent)
                , default_fireEvent_function_type(&FrameWindow_wrapper::default_fireEvent)
                , ( bp::arg("name"), bp::arg("args"), bp::arg("eventNamespace")="" ) );
        
        }
        { //::CEGUI::EventSet::fireEvent_impl
        
            typedef void ( FrameWindow_wrapper::*fireEvent_impl_function_type )( ::CEGUI::String const &,::CEGUI::EventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "fireEvent_impl"
                , fireEvent_impl_function_type( &FrameWindow_wrapper::fireEvent_impl )
                , ( bp::arg("name"), bp::arg("args") )
                , "! Implementation event firing member\n" );
        
        }
        { //::CEGUI::Window::generateAutoRepeatEvent
        
            typedef void ( FrameWindow_wrapper::*generateAutoRepeatEvent_function_type )( ::CEGUI::MouseButton ) ;
            
            FrameWindow_exposer.def( 
                "generateAutoRepeatEvent"
                , generateAutoRepeatEvent_function_type( &FrameWindow_wrapper::generateAutoRepeatEvent )
                , ( bp::arg("button") )
                , "*!\n\
            \n\
                Fires off a repeated mouse button down event for this window.\n\
            *\n" );
        
        }
        { //::CEGUI::NamedElement::getChildByNamePath_impl
        
            typedef ::CEGUI::NamedElement * ( FrameWindow_wrapper::*getChildByNamePath_impl_function_type )( ::CEGUI::String const & ) const;
            
            FrameWindow_exposer.def( 
                "getChildByNamePath_impl"
                , getChildByNamePath_impl_function_type( &FrameWindow_wrapper::default_getChildByNamePath_impl )
                , ( bp::arg("name_path") )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
             Retrieves a child at  name_path or 0 if none such exists\n\
            *\n" );
        
        }
        { //::CEGUI::NamedElement::getChildByNameRecursive_impl
        
            typedef ::CEGUI::NamedElement * ( FrameWindow_wrapper::*getChildByNameRecursive_impl_function_type )( ::CEGUI::String const & ) const;
            
            FrameWindow_exposer.def( 
                "getChildByNameRecursive_impl"
                , getChildByNameRecursive_impl_function_type( &FrameWindow_wrapper::default_getChildByNameRecursive_impl )
                , ( bp::arg("name") )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
             Finds a child by  name or 0 if none such exists\n\
            *\n" );
        
        }
        { //::CEGUI::Element::getClientChildContentArea
        
            typedef ::CEGUI::Element::CachedRectf const & ( ::CEGUI::Element::*getClientChildContentArea_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getClientChildContentArea"
                , getClientChildContentArea_function_type(&::CEGUI::Element::getClientChildContentArea)
                , bp::return_value_policy< bp::copy_const_reference >() );
        
        }
        { //::CEGUI::Window::getHitTestRect_impl
        
            typedef ::CEGUI::Rectf ( FrameWindow_wrapper::*getHitTestRect_impl_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getHitTestRect_impl"
                , getHitTestRect_impl_function_type( &FrameWindow_wrapper::default_getHitTestRect_impl )
                , "! Default implementation of function to return Window inner clipper area.\n\
            ! Default implementation of function to return Window hit-test area.\n" );
        
        }
        { //::CEGUI::Window::getInnerRectClipper_impl
        
            typedef ::CEGUI::Rectf ( FrameWindow_wrapper::*getInnerRectClipper_impl_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getInnerRectClipper_impl"
                , getInnerRectClipper_impl_function_type( &FrameWindow_wrapper::default_getInnerRectClipper_impl )
                , "! Default implementation of function to return Window outer clipper area.\n\
            ! Default implementation of function to return Window inner clipper area.\n" );
        
        }
        { //::CEGUI::Element::getNonClientChildContentArea
        
            typedef ::CEGUI::Element::CachedRectf const & ( ::CEGUI::Element::*getNonClientChildContentArea_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getNonClientChildContentArea"
                , getNonClientChildContentArea_function_type(&::CEGUI::Element::getNonClientChildContentArea)
                , bp::return_value_policy< bp::copy_const_reference >() );
        
        }
        { //::CEGUI::Window::getOuterRectClipper_impl
        
            typedef ::CEGUI::Rectf ( FrameWindow_wrapper::*getOuterRectClipper_impl_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getOuterRectClipper_impl"
                , getOuterRectClipper_impl_function_type( &FrameWindow_wrapper::default_getOuterRectClipper_impl )
                , "! Default implementation of function to return Window outer clipper area.\n" );
        
        }
        { //::CEGUI::Window::getParentElementClipIntersection
        
            typedef ::CEGUI::Rectf ( FrameWindow_wrapper::*getParentElementClipIntersection_function_type )( ::CEGUI::Rectf const & ) const;
            
            FrameWindow_exposer.def( 
                "getParentElementClipIntersection"
                , getParentElementClipIntersection_function_type( &FrameWindow_wrapper::getParentElementClipIntersection )
                , ( bp::arg("unclipped_area") )
                , "! helper function for calculating clipping rectangles.\n" );
        
        }
        { //::CEGUI::Window::getRenderedStringParser
        
            typedef ::CEGUI::RenderedStringParser & ( ::CEGUI::Window::*getRenderedStringParser_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getRenderedStringParser"
                , getRenderedStringParser_function_type(&::CEGUI::Window::getRenderedStringParser)
                , bp::return_value_policy< bp::reference_existing_object >() );
        
        }
        { //::CEGUI::Window::getRenderingContext_impl
        
            typedef void ( ::CEGUI::Window::*getRenderingContext_impl_function_type )( ::CEGUI::RenderingContext & ) const;
            typedef void ( FrameWindow_wrapper::*default_getRenderingContext_impl_function_type )( ::CEGUI::RenderingContext & ) const;
            
            FrameWindow_exposer.def( 
                "getRenderingContext_impl"
                , getRenderingContext_impl_function_type(&::CEGUI::Window::getRenderingContext_impl)
                , default_getRenderingContext_impl_function_type(&FrameWindow_wrapper::default_getRenderingContext_impl)
                , ( bp::arg("ctx") ) );
        
        }
        { //::CEGUI::Window::getRootContainerSize
        
            typedef ::CEGUI::Sizef const & ( ::CEGUI::Window::*getRootContainerSize_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getRootContainerSize"
                , getRootContainerSize_function_type(&::CEGUI::Window::getRootContainerSize)
                , bp::return_value_policy< bp::copy_const_reference >() );
        
        }
        { //::CEGUI::EventSet::getScriptModule
        
            typedef ::CEGUI::ScriptModule * ( FrameWindow_wrapper::*getScriptModule_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "getScriptModule"
                , getScriptModule_function_type( &FrameWindow_wrapper::getScriptModule )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "! Implementation event firing member\n\
            ! Helper to return the script module pointer or throw.\n" );
        
        }
        { //::CEGUI::Window::getUnclippedInnerRect_impl
        
            typedef ::CEGUI::Rectf ( FrameWindow_wrapper::*getUnclippedInnerRect_impl_function_type )( bool ) const;
            
            FrameWindow_exposer.def( 
                "getUnclippedInnerRect_impl"
                , getUnclippedInnerRect_impl_function_type( &FrameWindow_wrapper::default_getUnclippedInnerRect_impl )
                , ( bp::arg("skipAllPixelAlignment") ) );
        
        }
        { //::CEGUI::Element::getUnclippedOuterRect_impl
        
            typedef ::CEGUI::Rectf ( FrameWindow_wrapper::*getUnclippedOuterRect_impl_function_type )( bool ) const;
            
            FrameWindow_exposer.def( 
                "getUnclippedOuterRect_impl"
                , getUnclippedOuterRect_impl_function_type( &FrameWindow_wrapper::default_getUnclippedOuterRect_impl )
                , ( bp::arg("skipAllPixelAlignment") )
                , "! Default implementation of function to return Element's outer rect area.\n" );
        
        }
        { //::CEGUI::Window::getWindowAttachedToCommonAncestor
        
            typedef ::CEGUI::Window const * ( FrameWindow_wrapper::*getWindowAttachedToCommonAncestor_function_type )( ::CEGUI::Window const & ) const;
            
            FrameWindow_exposer.def( 
                "getWindowAttachedToCommonAncestor"
                , getWindowAttachedToCommonAncestor_function_type( &FrameWindow_wrapper::getWindowAttachedToCommonAncestor )
                , ( bp::arg("wnd") )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
            \n\
                Helper function to return the ancestor Window of a wnd that is attached\n\
                as a child to a window that is also an ancestor of a this.  Returns 0\n\
                if a wnd and a this are not part of the same hierachy.\n\
             *\n" );
        
        }
        { //::CEGUI::Window::handleFontRenderSizeChange
        
            typedef bool ( FrameWindow_wrapper::*handleFontRenderSizeChange_function_type )( ::CEGUI::EventArgs const & ) ;
            
            FrameWindow_exposer.def( 
                "handleFontRenderSizeChange"
                , handleFontRenderSizeChange_function_type( &FrameWindow_wrapper::default_handleFontRenderSizeChange )
                , ( bp::arg("args") )
                , "! handler function for when font render size changes.\n" );
        
        }
        { //::CEGUI::Window::initialiseClippers
        
            typedef void ( FrameWindow_wrapper::*initialiseClippers_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            FrameWindow_exposer.def( 
                "initialiseClippers"
                , initialiseClippers_function_type( &FrameWindow_wrapper::initialiseClippers )
                , ( bp::arg("ctx") )
                , "! Helper to intialise the needed clipping for geometry and render surface.\n" );
        
        }
        { //::CEGUI::Window::invalidate_impl
        
            typedef void ( FrameWindow_wrapper::*invalidate_impl_function_type )( bool const ) ;
            
            FrameWindow_exposer.def( 
                "invalidate_impl"
                , invalidate_impl_function_type( &FrameWindow_wrapper::invalidate_impl )
                , ( bp::arg("recursive") )
                , "! helper function to invalidate window and optionally child windows.\n" );
        
        }
        { //::CEGUI::Window::isHitTargetWindow
        
            typedef bool ( FrameWindow_wrapper::*isHitTargetWindow_function_type )( ::CEGUI::Vector2f const &,bool ) const;
            
            FrameWindow_exposer.def( 
                "isHitTargetWindow"
                , isHitTargetWindow_function_type( &FrameWindow_wrapper::isHitTargetWindow )
                , ( bp::arg("position"), bp::arg("allow_disabled") ) );
        
        }
        { //::CEGUI::Element::isInnerRectSizeChanged
        
            typedef bool ( FrameWindow_wrapper::*isInnerRectSizeChanged_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "isInnerRectSizeChanged"
                , isInnerRectSizeChanged_function_type( &FrameWindow_wrapper::isInnerRectSizeChanged )
                , "! helper to return whether the inner rect size has changed\n" );
        
        }
        { //::CEGUI::Window::isPropertyAtDefault
        
            typedef bool ( FrameWindow_wrapper::*isPropertyAtDefault_function_type )( ::CEGUI::Property const * ) const;
            
            FrameWindow_exposer.def( 
                "isPropertyAtDefault"
                , isPropertyAtDefault_function_type( &FrameWindow_wrapper::isPropertyAtDefault )
                , ( bp::arg("property") )
                , "*!\n\
            \n\
                Returns whether a property is at it's default value.\n\
                This function is different from Property.isDefatult as it takes the assigned look'n'feel\n\
                (if the is one) into account.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::isTopOfZOrder
        
            typedef bool ( FrameWindow_wrapper::*isTopOfZOrder_function_type )(  ) const;
            
            FrameWindow_exposer.def( 
                "isTopOfZOrder"
                , isTopOfZOrder_function_type( &FrameWindow_wrapper::isTopOfZOrder )
                , "*!\n\
                \n\
                    Return whether the window is at the top of the Z-Order.  This will\n\
                    correctly take into account 'Always on top' windows as needed.\n\
            \n\
                @return\n\
                    - true if the Window is at the top of the z-order in relation to sibling\n\
                      windows with the same 'always on top' setting.\n\
                    - false if the Window is not at the top of the z-order in relation to\n\
                      sibling windows with the same 'always on top' setting.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::layoutLookNFeelChildWidgets
        
            typedef void ( FrameWindow_wrapper::*layoutLookNFeelChildWidgets_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "layoutLookNFeelChildWidgets"
                , layoutLookNFeelChildWidgets_function_type( &FrameWindow_wrapper::layoutLookNFeelChildWidgets )
                , "mark the rect caches defined on Window invalid (does not affect Element)\n" );
        
        }
        { //::CEGUI::Window::markCachedWindowRectsInvalid
        
            typedef void ( FrameWindow_wrapper::*markCachedWindowRectsInvalid_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "markCachedWindowRectsInvalid"
                , markCachedWindowRectsInvalid_function_type( &FrameWindow_wrapper::markCachedWindowRectsInvalid )
                , "mark the rect caches defined on Window invalid (does not affect Element)\n" );
        
        }
        { //::CEGUI::Window::moveToFront_impl
        
            typedef bool ( FrameWindow_wrapper::*moveToFront_impl_function_type )( bool ) ;
            
            FrameWindow_exposer.def( 
                "moveToFront_impl"
                , moveToFront_impl_function_type( &FrameWindow_wrapper::default_moveToFront_impl )
                , ( bp::arg("wasClicked") )
                , "*!\n\
                \n\
                    Implements move to front behavior.\n\
            \n\
                @return\n\
                    Should return true if some action was taken, or false if there was\n\
                    nothing to be done.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::notifyChildrenOfSizeChange
        
            typedef void ( FrameWindow_wrapper::*notifyChildrenOfSizeChange_function_type )( bool const,bool const ) ;
            
            FrameWindow_exposer.def( 
                "notifyChildrenOfSizeChange"
                , notifyChildrenOfSizeChange_function_type( &FrameWindow_wrapper::notifyChildrenOfSizeChange )
                , ( bp::arg("non_client"), bp::arg("client") ) );
        
        }
        { //::CEGUI::Window::notifyClippingChanged
        
            typedef void ( FrameWindow_wrapper::*notifyClippingChanged_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "notifyClippingChanged"
                , notifyClippingChanged_function_type( &FrameWindow_wrapper::notifyClippingChanged )
                , "*!\n\
            \n\
                Recursively inform all children that the clipping has changed and screen rects\n\
                needs to be recached.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::notifyScreenAreaChanged
        
            typedef void ( ::CEGUI::Window::*notifyScreenAreaChanged_function_type )( bool ) ;
            typedef void ( FrameWindow_wrapper::*default_notifyScreenAreaChanged_function_type )( bool ) ;
            
            FrameWindow_exposer.def( 
                "notifyScreenAreaChanged"
                , notifyScreenAreaChanged_function_type(&::CEGUI::Window::notifyScreenAreaChanged)
                , default_notifyScreenAreaChanged_function_type(&FrameWindow_wrapper::default_notifyScreenAreaChanged)
                , ( bp::arg("recursive")=(bool)(true) ) );
        
        }
        { //::CEGUI::Window::onAlphaChanged
        
            typedef void ( FrameWindow_wrapper::*onAlphaChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onAlphaChanged"
                , onAlphaChanged_function_type( &FrameWindow_wrapper::default_onAlphaChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's alpha blend value is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onAlwaysOnTopChanged
        
            typedef void ( FrameWindow_wrapper::*onAlwaysOnTopChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onAlwaysOnTopChanged"
                , onAlwaysOnTopChanged_function_type( &FrameWindow_wrapper::default_onAlwaysOnTopChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's always-on-top setting is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onCaptureGained
        
            typedef void ( FrameWindow_wrapper::*onCaptureGained_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onCaptureGained"
                , onCaptureGained_function_type( &FrameWindow_wrapper::default_onCaptureGained )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window gains capture of mouse inputs.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onCharacter
        
            typedef void ( FrameWindow_wrapper::*onCharacter_function_type )( ::CEGUI::KeyEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onCharacter"
                , onCharacter_function_type( &FrameWindow_wrapper::default_onCharacter )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a character-key has been pressed while this window\n\
                    has input focus.\n\
            \n\
                @param e\n\
                    KeyEventArgs object whose 'codepoint' field is set to the Unicode code\n\
                    point (encoded as utf32) for the character typed, and whose 'sysKeys'\n\
                    field represents the combination of SystemKey that were active when the\n\
                    event was generated.  All other fields should be considered as 'junk'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onChildAdded
        
            typedef void ( FrameWindow_wrapper::*onChildAdded_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onChildAdded"
                , onChildAdded_function_type( &FrameWindow_wrapper::default_onChildAdded )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a child window is added to this window.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that has been added.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onChildRemoved
        
            typedef void ( FrameWindow_wrapper::*onChildRemoved_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onChildRemoved"
                , onChildRemoved_function_type( &FrameWindow_wrapper::default_onChildRemoved )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a child window is removed from this window.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set the window\n\
                    that has been removed.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onClippingChanged
        
            typedef void ( FrameWindow_wrapper::*onClippingChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onClippingChanged"
                , onClippingChanged_function_type( &FrameWindow_wrapper::default_onClippingChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for being clipped by it's\n\
                    parent is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDestructionStarted
        
            typedef void ( FrameWindow_wrapper::*onDestructionStarted_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onDestructionStarted"
                , onDestructionStarted_function_type( &FrameWindow_wrapper::default_onDestructionStarted )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window's destruction sequence has begun.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDisabled
        
            typedef void ( FrameWindow_wrapper::*onDisabled_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onDisabled"
                , onDisabled_function_type( &FrameWindow_wrapper::default_onDisabled )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is disabled.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDragDropItemDropped
        
            typedef void ( FrameWindow_wrapper::*onDragDropItemDropped_function_type )( ::CEGUI::DragDropEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onDragDropItemDropped"
                , onDragDropItemDropped_function_type( &FrameWindow_wrapper::default_onDragDropItemDropped )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a DragContainer is dragged over this window.\n\
            \n\
                @param e\n\
                    DragDropEventArgs object initialised as follows:\n\
                    - window field is normaly set to point to 'this' window.\n\
                    - dragDropItem is a pointer to a DragContainer window that triggered\n\
                      the event.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDragDropItemEnters
        
            typedef void ( FrameWindow_wrapper::*onDragDropItemEnters_function_type )( ::CEGUI::DragDropEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onDragDropItemEnters"
                , onDragDropItemEnters_function_type( &FrameWindow_wrapper::default_onDragDropItemEnters )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a DragContainer is dragged over this window.\n\
            \n\
                @param e\n\
                    DragDropEventArgs object initialised as follows:\n\
                    - window field is normaly set to point to 'this' window.\n\
                    - dragDropItem is a pointer to a DragContainer window that triggered\n\
                      the event.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDragDropItemLeaves
        
            typedef void ( FrameWindow_wrapper::*onDragDropItemLeaves_function_type )( ::CEGUI::DragDropEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onDragDropItemLeaves"
                , onDragDropItemLeaves_function_type( &FrameWindow_wrapper::default_onDragDropItemLeaves )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a DragContainer is dragged over this window.\n\
            \n\
                @param e\n\
                    DragDropEventArgs object initialised as follows:\n\
                    - window field is normaly set to point to 'this' window.\n\
                    - dragDropItem is a pointer to a DragContainer window that triggered\n\
                      the event.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onEnabled
        
            typedef void ( FrameWindow_wrapper::*onEnabled_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onEnabled"
                , onEnabled_function_type( &FrameWindow_wrapper::default_onEnabled )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is enabled.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onFontChanged
        
            typedef void ( FrameWindow_wrapper::*onFontChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onFontChanged"
                , onFontChanged_function_type( &FrameWindow_wrapper::default_onFontChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's font is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onHidden
        
            typedef void ( FrameWindow_wrapper::*onHidden_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onHidden"
                , onHidden_function_type( &FrameWindow_wrapper::default_onHidden )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is hidden.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::onHorizontalAlignmentChanged
        
            typedef void ( FrameWindow_wrapper::*onHorizontalAlignmentChanged_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onHorizontalAlignmentChanged"
                , onHorizontalAlignmentChanged_function_type( &FrameWindow_wrapper::default_onHorizontalAlignmentChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the horizontal alignment setting for the element is\n\
                    changed.\n\
            \n\
                @param e\n\
                    ElementEventArgs object initialised as follows:\n\
                    - element field is set to point to the element object who's alignment has\n\
                      changed (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onIDChanged
        
            typedef void ( FrameWindow_wrapper::*onIDChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onIDChanged"
                , onIDChanged_function_type( &FrameWindow_wrapper::default_onIDChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's client assigned ID is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onInheritsAlphaChanged
        
            typedef void ( FrameWindow_wrapper::*onInheritsAlphaChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onInheritsAlphaChanged"
                , onInheritsAlphaChanged_function_type( &FrameWindow_wrapper::default_onInheritsAlphaChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for inheriting alpha-blending\n\
                    is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onInvalidated
        
            typedef void ( FrameWindow_wrapper::*onInvalidated_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onInvalidated"
                , onInvalidated_function_type( &FrameWindow_wrapper::default_onInvalidated )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window gets invalidated.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onKeyDown
        
            typedef void ( FrameWindow_wrapper::*onKeyDown_function_type )( ::CEGUI::KeyEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onKeyDown"
                , onKeyDown_function_type( &FrameWindow_wrapper::default_onKeyDown )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a key as been depressed while this window has input\n\
                    focus.\n\
            \n\
                @param e\n\
                    KeyEventArgs object whose 'scancode' field is set to the Key.Scan value\n\
                    representing the key that was pressed, and whose 'sysKeys' field\n\
                    represents the combination of SystemKey that were active when the event\n\
                    was generated.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onKeyUp
        
            typedef void ( FrameWindow_wrapper::*onKeyUp_function_type )( ::CEGUI::KeyEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onKeyUp"
                , onKeyUp_function_type( &FrameWindow_wrapper::default_onKeyUp )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a key as been released while this window has input\n\
                    focus.\n\
            \n\
                @param e\n\
                    KeyEventArgs object whose 'scancode' field is set to the Key.Scan value\n\
                    representing the key that was released, and whose 'sysKeys' field\n\
                    represents the combination of SystemKey that were active when the event\n\
                    was generated.  All other fields should be considered as 'junk'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMarginChanged
        
            typedef void ( FrameWindow_wrapper::*onMarginChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMarginChanged"
                , onMarginChanged_function_type( &FrameWindow_wrapper::default_onMarginChanged )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::Window::onMouseClicked
        
            typedef void ( FrameWindow_wrapper::*onMouseClicked_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMouseClicked"
                , onMouseClicked_function_type( &FrameWindow_wrapper::default_onMouseClicked )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a mouse button has been clicked (that is depressed\n\
                    and then released, within a specified time) within this window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseDoubleClicked
        
            typedef void ( FrameWindow_wrapper::*onMouseDoubleClicked_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMouseDoubleClicked"
                , onMouseDoubleClicked_function_type( &FrameWindow_wrapper::default_onMouseDoubleClicked )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a mouse button has been double-clicked within this\n\
                    window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseEnters
        
            typedef void ( FrameWindow_wrapper::*onMouseEnters_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMouseEnters"
                , onMouseEnters_function_type( &FrameWindow_wrapper::default_onMouseEnters )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor has entered this window's area and\n\
                    is actually over some part of this windows surface and not, for\n\
                    instance over a child window - even though technically in those cases\n\
                    the mouse is also within this Window's area, the handler will not be\n\
                    called.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
            \n\
                @see\n\
                    Window.onMouseEntersArea\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseEntersArea
        
            typedef void ( FrameWindow_wrapper::*onMouseEntersArea_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMouseEntersArea"
                , onMouseEntersArea_function_type( &FrameWindow_wrapper::default_onMouseEntersArea )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor has entered this window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseLeaves
        
            typedef void ( FrameWindow_wrapper::*onMouseLeaves_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMouseLeaves"
                , onMouseLeaves_function_type( &FrameWindow_wrapper::default_onMouseLeaves )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor is no longer over this window's\n\
                    surface area.  This will be called when the mouse is not over a part\n\
                    of this Window's actual surface - even though technically the mouse is\n\
                    still within the Window's area, for example if the mouse moves over a\n\
                    child window.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
            \n\
                @see\n\
                    Window.onMouseLeavesArea\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseLeavesArea
        
            typedef void ( FrameWindow_wrapper::*onMouseLeavesArea_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMouseLeavesArea"
                , onMouseLeavesArea_function_type( &FrameWindow_wrapper::default_onMouseLeavesArea )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor has left this window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseTripleClicked
        
            typedef void ( FrameWindow_wrapper::*onMouseTripleClicked_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMouseTripleClicked"
                , onMouseTripleClicked_function_type( &FrameWindow_wrapper::default_onMouseTripleClicked )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a mouse button has been triple-clicked within this\n\
                    window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseWheel
        
            typedef void ( FrameWindow_wrapper::*onMouseWheel_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMouseWheel"
                , onMouseWheel_function_type( &FrameWindow_wrapper::default_onMouseWheel )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse wheel (z-axis) position changes within\n\
                    this window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMoved
        
            typedef void ( FrameWindow_wrapper::*onMoved_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onMoved"
                , onMoved_function_type( &FrameWindow_wrapper::default_onMoved )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's position changes.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::NamedElement::onNameChanged
        
            typedef void ( FrameWindow_wrapper::*onNameChanged_function_type )( ::CEGUI::NamedElementEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onNameChanged"
                , onNameChanged_function_type( &FrameWindow_wrapper::default_onNameChanged )
                , ( bp::arg("e") )
                , "*!\n\
                 Handler called when the element's name changes.\n\
            \n\
                @param e\n\
                    NamedElementEventArgs object whose 'element' pointer field is set to the element\n\
                    that triggered the event. For this event the trigger element is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::onNonClientChanged
        
            typedef void ( FrameWindow_wrapper::*onNonClientChanged_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onNonClientChanged"
                , onNonClientChanged_function_type( &FrameWindow_wrapper::default_onNonClientChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the element's non-client setting, affecting it's\n\
                    position and size relative to it's parent is changed.\n\
            \n\
                @param e\n\
                    ElementEventArgs object whose 'element' pointer field is set to the element\n\
                    that triggered the event. For this event the trigger element is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onParentDestroyChanged
        
            typedef void ( FrameWindow_wrapper::*onParentDestroyChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onParentDestroyChanged"
                , onParentDestroyChanged_function_type( &FrameWindow_wrapper::default_onParentDestroyChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for being destroyed\n\
                    automatically be it's parent is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onParentSized
        
            typedef void ( FrameWindow_wrapper::*onParentSized_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onParentSized"
                , onParentSized_function_type( &FrameWindow_wrapper::default_onParentSized )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window's parent window has been resized.  If\n\
                    this window is the root  GUI Sheet window, this call will be made when\n\
                    the display size changes.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set the the\n\
                    window that caused the event; this is typically either this window's\n\
                    parent window, or NULL to indicate the screen size has changed.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onRenderingEnded
        
            typedef void ( FrameWindow_wrapper::*onRenderingEnded_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onRenderingEnded"
                , onRenderingEnded_function_type( &FrameWindow_wrapper::default_onRenderingEnded )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when rendering for this window has ended.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onRenderingStarted
        
            typedef void ( FrameWindow_wrapper::*onRenderingStarted_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onRenderingStarted"
                , onRenderingStarted_function_type( &FrameWindow_wrapper::default_onRenderingStarted )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when rendering for this window has started.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onRotated
        
            typedef void ( FrameWindow_wrapper::*onRotated_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onRotated"
                , onRotated_function_type( &FrameWindow_wrapper::default_onRotated )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::Window::onShown
        
            typedef void ( FrameWindow_wrapper::*onShown_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onShown"
                , onShown_function_type( &FrameWindow_wrapper::default_onShown )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is shown (made visible).\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onSized
        
            typedef void ( FrameWindow_wrapper::*onSized_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onSized"
                , onSized_function_type( &FrameWindow_wrapper::default_onSized )
                , ( bp::arg("e") )
                , "*************************************************************************\n\
                    Event trigger methods\n\
                *************************************************************************\n\
                *!\n\
                \n\
                    Handler called when the window's size changes.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onTextParsingChanged
        
            typedef void ( FrameWindow_wrapper::*onTextParsingChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onTextParsingChanged"
                , onTextParsingChanged_function_type( &FrameWindow_wrapper::default_onTextParsingChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for whether text parsing is\n\
                    enabled is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::onVerticalAlignmentChanged
        
            typedef void ( FrameWindow_wrapper::*onVerticalAlignmentChanged_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onVerticalAlignmentChanged"
                , onVerticalAlignmentChanged_function_type( &FrameWindow_wrapper::default_onVerticalAlignmentChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the vertical alignment setting for the element is\n\
                    changed.\n\
            \n\
                @param e\n\
                    ElementEventArgs object initialised as follows:\n\
                    - element field is set to point to the element object who's alignment has\n\
                      changed (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onWindowRendererAttached
        
            typedef void ( FrameWindow_wrapper::*onWindowRendererAttached_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onWindowRendererAttached"
                , onWindowRendererAttached_function_type( &FrameWindow_wrapper::default_onWindowRendererAttached )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a new window renderer object is attached.\n\
            \n\
                @param e\n\
                    WindowEventArgs object initialised as follows:\n\
                    - window field is set to point to the Window object that just got a new\n\
                      window renderer attached. (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onWindowRendererDetached
        
            typedef void ( FrameWindow_wrapper::*onWindowRendererDetached_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onWindowRendererDetached"
                , onWindowRendererDetached_function_type( &FrameWindow_wrapper::default_onWindowRendererDetached )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the currently attached window renderer object is detached.\n\
            \n\
                @param e\n\
                    WindowEventArgs object initialised as follows:\n\
                    - window field is set to point to the Window object that just got lost its\n\
                      window renderer. (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onZChange_impl
        
            typedef void ( FrameWindow_wrapper::*onZChange_impl_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "onZChange_impl"
                , onZChange_impl_function_type( &FrameWindow_wrapper::default_onZChange_impl )
                , "*!\n\
            \n\
                Notify 'this' and all siblings of a ZOrder change event\n\
            *\n" );
        
        }
        { //::CEGUI::Window::onZChanged
        
            typedef void ( FrameWindow_wrapper::*onZChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            FrameWindow_exposer.def( 
                "onZChanged"
                , onZChanged_function_type( &FrameWindow_wrapper::default_onZChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the z-order position of this window has changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::performChildWindowLayout
        
            typedef void ( ::CEGUI::Window::*performChildWindowLayout_function_type )( bool,bool ) ;
            typedef void ( FrameWindow_wrapper::*default_performChildWindowLayout_function_type )( bool,bool ) ;
            
            FrameWindow_exposer.def( 
                "performChildWindowLayout"
                , performChildWindowLayout_function_type(&::CEGUI::Window::performChildWindowLayout)
                , default_performChildWindowLayout_function_type(&FrameWindow_wrapper::default_performChildWindowLayout)
                , ( bp::arg("nonclient_sized_hint")=(bool)(false), bp::arg("client_sized_hint")=(bool)(false) ) );
        
        }
        { //::CEGUI::Window::performCopy
        
            typedef bool ( ::CEGUI::Window::*performCopy_function_type )( ::CEGUI::Clipboard & ) ;
            typedef bool ( FrameWindow_wrapper::*default_performCopy_function_type )( ::CEGUI::Clipboard & ) ;
            
            FrameWindow_exposer.def( 
                "performCopy"
                , performCopy_function_type(&::CEGUI::Window::performCopy)
                , default_performCopy_function_type(&FrameWindow_wrapper::default_performCopy)
                , ( bp::arg("clipboard") ) );
        
        }
        { //::CEGUI::Window::performCut
        
            typedef bool ( ::CEGUI::Window::*performCut_function_type )( ::CEGUI::Clipboard & ) ;
            typedef bool ( FrameWindow_wrapper::*default_performCut_function_type )( ::CEGUI::Clipboard & ) ;
            
            FrameWindow_exposer.def( 
                "performCut"
                , performCut_function_type(&::CEGUI::Window::performCut)
                , default_performCut_function_type(&FrameWindow_wrapper::default_performCut)
                , ( bp::arg("clipboard") ) );
        
        }
        { //::CEGUI::Window::performPaste
        
            typedef bool ( ::CEGUI::Window::*performPaste_function_type )( ::CEGUI::Clipboard & ) ;
            typedef bool ( FrameWindow_wrapper::*default_performPaste_function_type )( ::CEGUI::Clipboard & ) ;
            
            FrameWindow_exposer.def( 
                "performPaste"
                , performPaste_function_type(&::CEGUI::Window::performPaste)
                , default_performPaste_function_type(&FrameWindow_wrapper::default_performPaste)
                , ( bp::arg("clipboard") ) );
        
        }
        { //::CEGUI::Window::populateGeometryBuffer
        
            typedef void ( FrameWindow_wrapper::*populateGeometryBuffer_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "populateGeometryBuffer"
                , populateGeometryBuffer_function_type( &FrameWindow_wrapper::default_populateGeometryBuffer )
                , "*!\n\
                \n\
                    Update the rendering cache.\n\
            \n\
                    Populates the Window's GeometryBuffer ready for rendering.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::queueGeometry
        
            typedef void ( FrameWindow_wrapper::*queueGeometry_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            FrameWindow_exposer.def( 
                "queueGeometry"
                , queueGeometry_function_type( &FrameWindow_wrapper::queueGeometry )
                , ( bp::arg("ctx") )
                , "*!\n\
                \n\
                    Perform drawing operations concerned with positioning, clipping and\n\
                    queueing of window geometry to RenderingSurfaces.\n\
            \n\
                \note\n\
                    This function is a sub-function of drawSelf and is provided to make it\n\
                    easier to override drawSelf without needing to duplicate large sections\n\
                    of the code from the default implementation.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::releaseRenderingWindow
        
            typedef void ( FrameWindow_wrapper::*releaseRenderingWindow_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "releaseRenderingWindow"
                , releaseRenderingWindow_function_type( &FrameWindow_wrapper::releaseRenderingWindow )
                , "! helper to clean up the auto RenderingWindow surface\n" );
        
        }
        { //::CEGUI::Window::removeChild_impl
        
            typedef void ( FrameWindow_wrapper::*removeChild_impl_function_type )( ::CEGUI::Element * ) ;
            
            FrameWindow_exposer.def( 
                "removeChild_impl"
                , removeChild_impl_function_type( &FrameWindow_wrapper::default_removeChild_impl )
                , ( bp::arg("element") )
                , "*!\n\
            opydoc Element.removeChild_impl\n\
            *\n" );
        
        }
        { //::CEGUI::Window::removeWindowFromDrawList
        
            typedef void ( FrameWindow_wrapper::*removeWindowFromDrawList_function_type )( ::CEGUI::Window const & ) ;
            
            FrameWindow_exposer.def( 
                "removeWindowFromDrawList"
                , removeWindowFromDrawList_function_type( &FrameWindow_wrapper::removeWindowFromDrawList )
                , ( bp::arg("wnd") )
                , "*!\n\
                \n\
                    Removes the window from the drawing list.  If the window is not attached\n\
                    to the drawing list then nothing happens.\n\
            \n\
                @param wnd\n\
                    Window object to be removed from the drawing list.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::setArea
        
            typedef void ( ::CEGUI::Element::*setArea_function_type )( ::CEGUI::UVector2 const &,::CEGUI::USize const & ) ;
            typedef void ( FrameWindow_wrapper::*default_setArea_function_type )( ::CEGUI::UVector2 const &,::CEGUI::USize const & ) ;
            
            FrameWindow_exposer.def( 
                "setArea"
                , setArea_function_type(&::CEGUI::Element::setArea)
                , default_setArea_function_type(&FrameWindow_wrapper::default_setArea)
                , ( bp::arg("pos"), bp::arg("size") ) );
        
        }
        { //::CEGUI::Element::setArea
        
            typedef void ( ::CEGUI::Element::*setArea_function_type )( ::CEGUI::UDim const &,::CEGUI::UDim const &,::CEGUI::UDim const &,::CEGUI::UDim const & ) ;
            
            FrameWindow_exposer.def( 
                "setArea"
                , setArea_function_type( &::CEGUI::Element::setArea )
                , ( bp::arg("xpos"), bp::arg("ypos"), bp::arg("width"), bp::arg("height") )
                , "!  overload\n" );
        
        }
        { //::CEGUI::Element::setArea
        
            typedef void ( ::CEGUI::Element::*setArea_function_type )( ::CEGUI::URect const & ) ;
            
            FrameWindow_exposer.def( 
                "setArea"
                , setArea_function_type( &::CEGUI::Element::setArea )
                , ( bp::arg("area") )
                , "!  overload\n" );
        
        }
        { //::CEGUI::Window::setArea_impl
        
            typedef void ( FrameWindow_wrapper::*setArea_impl_function_type )( ::CEGUI::UVector2 const &,::CEGUI::USize const &,bool,bool ) ;
            
            FrameWindow_exposer.def( 
                "setArea_impl"
                , setArea_impl_function_type( &FrameWindow_wrapper::default_setArea_impl )
                , ( bp::arg("pos"), bp::arg("size"), bp::arg("topLeftSizing")=(bool)(false), bp::arg("fireEvents")=(bool)(true) )
                , "! opydoc Element.setArea_impl\n" );
        
        }
        { //::CEGUI::Element::setHorizontalAlignment
        
            typedef void ( ::CEGUI::Element::*setHorizontalAlignment_function_type )( ::CEGUI::HorizontalAlignment const ) ;
            typedef void ( FrameWindow_wrapper::*default_setHorizontalAlignment_function_type )( ::CEGUI::HorizontalAlignment const ) ;
            
            FrameWindow_exposer.def( 
                "setHorizontalAlignment"
                , setHorizontalAlignment_function_type(&::CEGUI::Element::setHorizontalAlignment)
                , default_setHorizontalAlignment_function_type(&FrameWindow_wrapper::default_setHorizontalAlignment)
                , ( bp::arg("alignment") ) );
        
        }
        { //::CEGUI::Window::setLookNFeel
        
            typedef void ( ::CEGUI::Window::*setLookNFeel_function_type )( ::CEGUI::String const & ) ;
            typedef void ( FrameWindow_wrapper::*default_setLookNFeel_function_type )( ::CEGUI::String const & ) ;
            
            FrameWindow_exposer.def( 
                "setLookNFeel"
                , setLookNFeel_function_type(&::CEGUI::Window::setLookNFeel)
                , default_setLookNFeel_function_type(&FrameWindow_wrapper::default_setLookNFeel)
                , ( bp::arg("look") ) );
        
        }
        { //::CEGUI::Window::setMargin
        
            typedef void ( ::CEGUI::Window::*setMargin_function_type )( ::CEGUI::UBox const & ) ;
            typedef void ( FrameWindow_wrapper::*default_setMargin_function_type )( ::CEGUI::UBox const & ) ;
            
            FrameWindow_exposer.def( 
                "setMargin"
                , setMargin_function_type(&::CEGUI::Window::setMargin)
                , default_setMargin_function_type(&FrameWindow_wrapper::default_setMargin)
                , ( bp::arg("margin") ) );
        
        }
        { //::CEGUI::NamedElement::setName
        
            typedef void ( ::CEGUI::NamedElement::*setName_function_type )( ::CEGUI::String const & ) ;
            typedef void ( FrameWindow_wrapper::*default_setName_function_type )( ::CEGUI::String const & ) ;
            
            FrameWindow_exposer.def( 
                "setName"
                , setName_function_type(&::CEGUI::NamedElement::setName)
                , default_setName_function_type(&FrameWindow_wrapper::default_setName)
                , ( bp::arg("name") ) );
        
        }
        { //::CEGUI::Window::setParent
        
            typedef void ( FrameWindow_wrapper::*setParent_function_type )( ::CEGUI::Element * ) ;
            
            FrameWindow_exposer.def( 
                "setParent"
                , setParent_function_type( &FrameWindow_wrapper::default_setParent )
                , ( bp::arg("parent") )
                , "*!\n\
                \n\
                    Set the parent window for this window object.\n\
            \n\
                @param parent\n\
                    Pointer to a Window object that is to be assigned as the parent to this\n\
                    Window.\n\
            \n\
                @return\n\
                    Nothing\n\
                *\n" );
        
        }
        { //::CEGUI::Element::setVerticalAlignment
        
            typedef void ( ::CEGUI::Element::*setVerticalAlignment_function_type )( ::CEGUI::VerticalAlignment const ) ;
            typedef void ( FrameWindow_wrapper::*default_setVerticalAlignment_function_type )( ::CEGUI::VerticalAlignment const ) ;
            
            FrameWindow_exposer.def( 
                "setVerticalAlignment"
                , setVerticalAlignment_function_type(&::CEGUI::Element::setVerticalAlignment)
                , default_setVerticalAlignment_function_type(&FrameWindow_wrapper::default_setVerticalAlignment)
                , ( bp::arg("alignment") ) );
        
        }
        { //::CEGUI::EventSet::subscribeScriptedEvent
        
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( ::CEGUI::EventSet::*subscribeScriptedEvent_function_type )( ::CEGUI::String const &,::CEGUI::String const & ) ;
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( FrameWindow_wrapper::*default_subscribeScriptedEvent_function_type )( ::CEGUI::String const &,::CEGUI::String const & ) ;
            
            FrameWindow_exposer.def( 
                "subscribeScriptedEvent"
                , subscribeScriptedEvent_function_type(&::CEGUI::EventSet::subscribeScriptedEvent)
                , default_subscribeScriptedEvent_function_type(&FrameWindow_wrapper::default_subscribeScriptedEvent)
                , ( bp::arg("name"), bp::arg("subscriber_name") ) );
        
        }
        { //::CEGUI::EventSet::subscribeScriptedEvent
        
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( ::CEGUI::EventSet::*subscribeScriptedEvent_function_type )( ::CEGUI::String const &,unsigned int,::CEGUI::String const & ) ;
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( FrameWindow_wrapper::*default_subscribeScriptedEvent_function_type )( ::CEGUI::String const &,unsigned int,::CEGUI::String const & ) ;
            
            FrameWindow_exposer.def( 
                "subscribeScriptedEvent"
                , subscribeScriptedEvent_function_type(&::CEGUI::EventSet::subscribeScriptedEvent)
                , default_subscribeScriptedEvent_function_type(&FrameWindow_wrapper::default_subscribeScriptedEvent)
                , ( bp::arg("name"), bp::arg("group"), bp::arg("subscriber_name") ) );
        
        }
        { //::CEGUI::Window::transferChildSurfaces
        
            typedef void ( FrameWindow_wrapper::*transferChildSurfaces_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "transferChildSurfaces"
                , transferChildSurfaces_function_type( &FrameWindow_wrapper::transferChildSurfaces )
                , "! transfer RenderingSurfaces to be owned by our target RenderingSurface.\n" );
        
        }
        { //::CEGUI::Window::update
        
            typedef void ( ::CEGUI::Window::*update_function_type )( float ) ;
            typedef void ( FrameWindow_wrapper::*default_update_function_type )( float ) ;
            
            FrameWindow_exposer.def( 
                "update"
                , update_function_type(&::CEGUI::Window::update)
                , default_update_function_type(&FrameWindow_wrapper::default_update)
                , ( bp::arg("elapsed") ) );
        
        }
        { //::CEGUI::Window::updateGeometryRenderSettings
        
            typedef void ( FrameWindow_wrapper::*updateGeometryRenderSettings_function_type )(  ) ;
            
            FrameWindow_exposer.def( 
                "updateGeometryRenderSettings"
                , updateGeometryRenderSettings_function_type( &FrameWindow_wrapper::updateGeometryRenderSettings )
                , "*!\n\
            \n\
                Update position and clip region on this Windows geometry  rendering\n\
                surface.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::updateSelf
        
            typedef void ( FrameWindow_wrapper::*updateSelf_function_type )( float ) ;
            
            FrameWindow_exposer.def( 
                "updateSelf"
                , updateSelf_function_type( &FrameWindow_wrapper::default_updateSelf )
                , ( bp::arg("elapsed") )
                , "*************************************************************************\n\
                    Implementation Functions\n\
                *************************************************************************\n\
                *!\n\
                \n\
                    Perform actual update processing for this Window.\n\
            \n\
                @param elapsed\n\
                    float value indicating the number of seconds elapsed since the last\n\
                    update call.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::validateWindowRenderer
        
            typedef bool ( FrameWindow_wrapper::*validateWindowRenderer_function_type )( ::CEGUI::WindowRenderer const * ) const;
            
            FrameWindow_exposer.def( 
                "validateWindowRenderer"
                , validateWindowRenderer_function_type( &FrameWindow_wrapper::default_validateWindowRenderer )
                , ( bp::arg("renderer") )
                , "*!\n\
                \n\
                    Function used in checking if a WindowRenderer is valid for this window.\n\
            \n\
                @param renderer\n\
                  Window renderer that will be checked (it can be null!)\n\
            \n\
                @return\n\
                    Returns true if the given WindowRenderer class name is valid for this window.\n\
                    False if not.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::writeAutoChildWindowXML
        
            typedef bool ( FrameWindow_wrapper::*writeAutoChildWindowXML_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            FrameWindow_exposer.def( 
                "writeAutoChildWindowXML"
                , writeAutoChildWindowXML_function_type( &FrameWindow_wrapper::default_writeAutoChildWindowXML )
                , ( bp::arg("xml_stream") ) );
        
        }
        { //::CEGUI::Window::writeChildWindowsXML
        
            typedef int ( FrameWindow_wrapper::*writeChildWindowsXML_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            FrameWindow_exposer.def( 
                "writeChildWindowsXML"
                , writeChildWindowsXML_function_type( &FrameWindow_wrapper::default_writeChildWindowsXML )
                , ( bp::arg("xml_stream") ) );
        
        }
        { //::CEGUI::Window::writePropertiesXML
        
            typedef int ( FrameWindow_wrapper::*writePropertiesXML_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            FrameWindow_exposer.def( 
                "writePropertiesXML"
                , writePropertiesXML_function_type( &FrameWindow_wrapper::default_writePropertiesXML )
                , ( bp::arg("xml_stream") ) );
        
        }
        { //::CEGUI::Window::writeXMLToStream
        
            typedef void ( ::CEGUI::Window::*writeXMLToStream_function_type )( ::CEGUI::XMLSerializer & ) const;
            typedef void ( FrameWindow_wrapper::*default_writeXMLToStream_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            FrameWindow_exposer.def( 
                "writeXMLToStream"
                , writeXMLToStream_function_type(&::CEGUI::Window::writeXMLToStream)
                , default_writeXMLToStream_function_type(&FrameWindow_wrapper::default_writeXMLToStream)
                , ( bp::arg("xml_stream") ) );
        
        }
    }

}
